#
# spec file for package cloud-init
#
# Copyright (c) 2019 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# change this whenever config changes incompatible
%global configver 0.7

Name:           cloud-init
Version:        19.1
Release:        lp151.2.6.1
License:        GPL-3.0 and AGPL-3.0
Summary:        Cloud node initialization tool
Url:            http://launchpad.net/cloud-init/
Group:          System/Management
Source0:        %{name}-%{version}.tar.gz
Source1:        rsyslog-cloud-init.cfg


# FIXME 
# python2 disables SIGPIPE, causing broken pipe errors in shell scripts (bsc#903449)
Patch20:        cloud-init-python2-sigpipe.patch
Patch21:        cloud-init-template-py2.patch
Patch29:        datasourceLocalDisk.patch
Patch34:        cloud-init-tests-set-exec.patch
# FIXME no proposed solution
Patch38:        cloud-init-sysconf-path.patch
# FIXME (lp# 1800854)
Patch41:        cloud-init-static-net.patch
# FIXME (lp#1801364)
Patch42:        cloud-init-ostack-metadat-dencode.patch
# FIXME (lp#1812117)
Patch43:        cloud-init-write-routes.patch
# FIXME (lp#1817368)
Patch47:        cloud-init-trigger-udev.patch
# FIXME (lp#1669875) patch by mvoelker@launchpad
Patch48:        cloud-init-detect-nova.diff
# FIXME (lp#1821102)
Patch49:        cloud-init-add-static-routes.diff
# FIXME (lp#1843634)
Patch50:        cloud-init-noresolv-merge-no-dns-data.diff
# FIXME
Patch51:        cloud-init-after-wicked.patch

BuildRequires:  fdupes
BuildRequires:  filesystem
# pkg-config is needed to find correct systemd unit dir
BuildRequires:  pkg-config
# needed for /lib/udev
BuildRequires:  udev
%if 0%{?suse_version} > 1320
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Test requirements
BuildRequires:  python3-Jinja2
BuildRequires:  python3-PyYAML
BuildRequires:  python3-configobj >= 5.0.2
BuildRequires:  python3-httpretty
BuildRequires:  python3-jsonpatch
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-oauthlib
BuildRequires:  python3-requests
BuildRequires:  python3-testtools
%else
BuildRequires:  python-devel
BuildRequires:  python-Jinja2
BuildRequires:  python-PyYAML
BuildRequires:  python-requests
BuildRequires:  python-setuptools
BuildRequires:  python-six
%endif
%if 0%{?is_opensuse}
BuildRequires:  openSUSE-release
%else
BuildRequires:  sles-release
%endif
BuildRequires:  util-linux
Requires:       bash
Requires:       dhcp-client
Requires:       file
Requires:       growpart
Requires:       e2fsprogs
Requires:	    net-tools
Requires:       openssh
%if 0%{?suse_version} > 1320
Requires:       python3-configobj >= 5.0.2
Requires:       python3-Jinja2
Requires:       python3-jsonpatch
Requires:       python3-jsonschema
Requires:       python3-oauthlib
Requires:       python3-pyserial
Requires:       python3-PyYAML
Requires:       python3-requests
Requires:       python3-setuptools
Requires:       python3-six
Requires:       python3-xml
%else
Requires:       python-argparse
Requires:       python-configobj >= 5.0.2
Requires:       python-Jinja2
Requires:       python-jsonpatch
Requires:       python-jsonschema
Requires:       python-oauthlib
Requires:       python-pyserial
Requires:       python-PyYAML
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-six
Requires:       python-xml
%endif
Requires:       sudo
Requires:       util-linux
Requires:       cloud-init-config = %configver
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define         docdir %{_defaultdocdir}/%{name}
%ifarch %ix86 x86_64
Requires:       dmidecode
%endif
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
%define initsys sysvinit_suse
%else
%define initsys systemd
BuildRequires: pkgconfig(systemd)
%{?systemd_requires}
%if 0%{?suse_version} && 0%{?suse_version} == 1220
%define systemd_prefix /lib
%else
%define systemd_prefix /usr/lib
%endif
%endif
%if 0%{?suse_version} && 0%{?suse_version} >= 1315
Requires:      wicked-service
%else
Requires:      sysconfig-network
%endif

%description
Cloud-init is an init script that initializes a cloud node (VM)
according to the fetched configuration data from the admin node.

%package config-suse
Summary:        Configuration file for Cloud node initialization tool
Provides:	cloud-init-config = %configver
Group:          System/Management
Conflicts:	otherproviders(cloud-init-config)

%description config-suse
This package contains the product specific configuration file
for cloud-init.

%package doc
Summary:        Cloud node initialization tool - Documentation
Group:          System/Management
Recommends:     cloud-init = %{version}

%description doc
Cloud-init is an init script that initializes a cloud node (VM)
according to the fetched configuration data from the admin node.

Documentation and examples for cloud-init tools

#%package test
#Summary:        Cloud node initialization tool  - Testsuite
#Group:          System/Management
#Requires:       cloud-init = %{version}
#
#%description test
#Cloud-init is an init script that initializes a cloud node (VM)
#according to the fetched configuration data from the admin node.
#
#Unit tests for the cloud-init tools

%prep
%setup -q
%if 0%{?suse_version} < 1315
%patch20
%patch21 
%endif
%patch29 -p0
%patch34
%patch38
%patch41
%patch42
%patch43
%patch47
%patch48 -p1
%patch49 -p1
%patch50 -p1
%patch51 -p1

%build
%if 0%{?suse_version} && 0%{?suse_version} <= 1315
python setup.py build
%else
python3 setup.py build
%endif


%if 0%{?suse_version} > 1320
%check
# these tests are currently failing due to suse patches
rm -v tests/unittests/test_distros/test_netconfig.py
rm -v tests/unittests/test_net.py
# Ignore test failure currently not doing anything with opennebula
rm -v tests/unittests/test_datasource/test_opennebula.py
# To be investigated
rm -v tests/unittests/test_handler/test_handler_ntp.py
make test
%endif


%install
%if 0%{?suse_version} && 0%{?suse_version} <= 1315
python setup.py install --root=%{buildroot} --prefix=%{_prefix} --install-lib=%{python_sitelib} --init-system=%{initsys}
%else
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix} --install-lib=%{python3_sitelib} --init-system=%{initsys}
%endif
find %{buildroot} \( -name .gitignore -o -name .placeholder \) -delete
# from debian install script
for x in "%{buildroot}%{_bindir}/"*.py; do
   [ -f "${x}" ] && mv "${x}" "${x%.py}"
done
mkdir -p %{buildroot}%{_localstatedir}/lib/cloud
# move documentation
mkdir -p %{buildroot}%{_defaultdocdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{docdir}
# copy the LICENSE
cp LICENSE %{buildroot}%{docdir}
# Set the distribution indicator
%if 0%{?suse_version}
%if 0%{?is_opensuse}
sed -i s/suse/opensuse/ %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
%else
sed -i s/suse/sles/ %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
%endif
%endif
mkdir -p %{buildroot}/%{_sysconfdir}/rsyslog.d
mkdir -p %{buildroot}/usr/lib/udev/rules.d/
cp -a %{SOURCE1} %{buildroot}/%{_sysconfdir}/rsyslog.d/21-cloudinit.conf
mv %{buildroot}/lib/udev/rules.d/66-azure-ephemeral.rules %{buildroot}/usr/lib/udev/rules.d/

# remove debian/ubuntu specific profile.d file (bnc#779553)
rm -f %{buildroot}%{_sysconfdir}/profile.d/Z99-cloud-locale-test.sh

# Remove non-SUSE templates
rm %{buildroot}/%{_sysconfdir}/cloud/templates/*.debian.*
rm %{buildroot}/%{_sysconfdir}/cloud/templates/*.redhat.*
rm %{buildroot}/%{_sysconfdir}/cloud/templates/*.ubuntu.*

# move sysvinit scripts into the "right" place
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
mkdir -p %{buildroot}/%{_initddir}
mkdir -p %{buildroot}/%{_sbindir}
pushd "%{buildroot}%{_initddir}"
for iniF in *; do
    ln -s "%{_initddir}/${iniF}" "%{buildroot}/%{_sbindir}/rc${iniF}"
done
popd
%endif

# remove duplicate files
%if 0%{?suse_version}
%if 0%{?suse_version} <= 1315
%fdupes %{buildroot}%{python_sitelib}
%else
%fdupes %{buildroot}%{python3_sitelib}
%endif
%endif

%if 0%{?suse_version} && 0%{?suse_version} <= 1210
%postun
%insserv_cleanup
%endif

%files
%defattr(-,root,root)
# do not mark as doc or we get conflicts with the doc package
%{docdir}/LICENSE
%{_bindir}/cloud-id
%{_bindir}/cloud-init
%{_bindir}/cloud-init-per
%dir %{_sysconfdir}/cloud
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg.d
%config(noreplace) %{_sysconfdir}/cloud/templates
%{_sysconfdir}/dhcp/dhclient-exit-hooks.d/hook-dhclient
%{_sysconfdir}/NetworkManager/dispatcher.d/hook-network-manager
%if 0%{?suse_version} && 0%{?suse_version} < 1500
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%endif
%{_datadir}/bash-completion/completions/cloud-init
%if 0%{?suse_version} && 0%{?suse_version} <= 1315
%{python_sitelib}/cloudinit
%{python_sitelib}/cloud_init-%{version}-py%{py_ver}.egg-info
%else
%{python3_sitelib}/cloudinit
%{python3_sitelib}/cloud_init-%{version}-py%{py3_ver}.egg-info
%endif
%{_prefix}/lib/cloud-init
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
%{_sbindir}/rccloud-config
%{_sbindir}/rccloud-init
%{_sbindir}/rccloud-init-local
%{_sbindir}/rccloud-final
%attr(0755, root, root) %{_initddir}/cloud-config
%attr(0755, root, root) %{_initddir}/cloud-init
%attr(0755, root, root) %{_initddir}/cloud-init-local
%attr(0755, root, root) %{_initddir}/cloud-final
%else
%{systemd_prefix}/systemd/system-generators/cloud-init-generator
%{systemd_prefix}/systemd/system/cloud-config.service
%{systemd_prefix}/systemd/system/cloud-config.target
%{systemd_prefix}/systemd/system/cloud-init-local.service
%{systemd_prefix}/systemd/system/cloud-init.service
%{systemd_prefix}/systemd/system/cloud-init.target
%{systemd_prefix}/systemd/system/cloud-final.service
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1110
%dir %{_sysconfdir}/rsyslog.d
%{_sysconfdir}/rsyslog.d/21-cloudinit.conf
/usr/lib/udev/rules.d/66-azure-ephemeral.rules
# This if condition really distinquished between OBS and IBS.
# For SLE 12 builds in OBS owning the directories is not required, while
# SLE 12 builds in IBS require owning the directories
%else
/lib/udev/rules.d/66-azure-ephemeral.rules
%endif
%dir %attr(0755, root, root) %{_localstatedir}/lib/cloud
%dir %{docdir}
%dir /etc/NetworkManager
%dir /etc/NetworkManager/dispatcher.d
%dir /etc/dhcp
%dir /etc/dhcp/dhclient-exit-hooks.d

%files config-suse
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg

%files doc
%defattr(-,root,root)
%{docdir}/examples/*
%{docdir}/README
%{docdir}/*.txt
#%{docdir}/*.rst
%dir %{docdir}/examples

#%files test
#%defattr(-,root,root)
#%{python_sitelib}/tests

%changelog
* Tue Sep 24 2019 Robert Schweikert <rjschwei@suse.com>
- Add cloud-init-after-wicked.patch
  - Change the service order, the cloud-init service wants to run after
    networking is started
* Tue Sep 24 2019 Robert Schweikert <rjschwei@suse.com>
- Add cloud-init-noresolv-merge-no-dns-data.diff
  - Avoid writing resolv.conf if the network configuration contains no
    dns entries.
* Mon Sep 23 2019 Robert Schweikert <rjschwei@suse.com>
- Follow up to (bsc#1144363)
  - In this implementation the "name" is not yet an attribute, use
    get() to obtain the value from a dict. Source code version confusion.
* Mon Aug 19 2019 Robert Schweikert <rjschwei@suse.com>
- Add cloud-init-add-static-routes.diff (bsc#1141969)
  + Properly handle static routes. The EphemeralDHCP context manager did
    not parse or handle rfc3442 classless static routes which prevented
    reading datasource metadata in some clouds.
* Mon Aug 19 2019 Robert Schweikert <rjschwei@suse.com>
- Update cloud-init-trigger-udev.patch (bsc#1144363)
  - The __str__ implementation no longer delivers the name of the interface,
    use the "name" attribute instead to form a proper path in the
    sysfs tree
* Fri Aug 16 2019 Robert Schweikert <rjschwei@suse.com>
- Update cloud-init-write-routes.patch (bsc#1144881)
  + If no routes are set for a subnet but the subnet has a gateway
    specified, set the gateway as the default route for the interface
* Fri Jul  5 2019 Robert Schweikert <rjschwei@suse.com>
- Follow the ever changing inconsistencies of version definitions and
  detection in the build service.
  + No more suse_version in SUSE internal instance for SLES 15 SP1
* Tue Jun 11 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Fri May 31 2019 Robert Schweikert <rjschwei@suse.com>
- Update to version 19.1 (bsc#1136440)
  + Remove, included upstream
  - fix-default-systemd-unit-dir.patch
  - cloud-init-sysconf-ethsetup.patch
  - cloud-init-handle-def-route-set.patch
  - cloud-init-no-empty-resolv.patch
  - cloud-init-proper-ipv6-varname.patch
  + Forward port
  - cloud-init-trigger-udev.patch
  + Add cloud-init-detect-nova.diff (bsc#1136440)
  + Modify cloud-init-python2-sigpipe.patch, import signal and constants
  + Update spec to account for new location of bash completion
  + freebsd: add chpasswd pkg in the image [Gonéri Le Bouder]
  + tests: add Eoan release [Paride Legovini]
  + cc_mounts: check if mount -a on no-change fstab path
    [Jason Zions (MSFT)] (LP: #1825596)
  + replace remaining occurrences of LOG.warn [Daniel Watkins]
  + DataSourceAzure: Adjust timeout for polling IMDS [Anh Vo]
  + Azure: Changes to the Hyper-V KVP Reporter [Anh Vo]
  + git tests: no longer show warning about safe yaml.
  + tools/read-version: handle errors [Chad Miller]
  + net/sysconfig: only indicate available on known sysconfig distros
    (LP: #1819994)
  + packages: update rpm specs for new bash completion path
    [Daniel Watkins] (LP: #1825444)
  + test_azure: mock util.SeLinuxGuard where needed
    [Jason Zions (MSFT)] (LP: #1825253)
  + setup.py: install bash completion script in new location [Daniel Watkins]
  + mount_cb: do not pass sync and rw options to mount
    [Gonéri Le Bouder] (LP: #1645824)
  + cc_apt_configure: fix typo in apt documentation [Dominic Schlegel]
  + Revert "DataSource: move update_events from a class to an instance..."
    [Daniel Watkins]
  + Change DataSourceNoCloud to ignore file system label's case.
    [Risto Oikarinen]
  + cmd:main.py: Fix missing 'modules-init' key in modes dict
    [Antonio Romito] (LP: #1815109)
  + ubuntu_advantage: rewrite cloud-config module
  + Azure: Treat _unset network configuration as if it were absent
    [Jason Zions (MSFT)] (LP: #1823084)
  + DatasourceAzure: add additional logging for azure datasource [Anh Vo]
  + cloud_tests: fix apt_pipelining test-cases
  + Azure: Ensure platform random_seed is always serializable as JSON.
    [Jason Zions (MSFT)]
  + net/sysconfig: write out SUSE-compatible IPv6 config [Robert Schweikert]
  + tox: Update testenv for openSUSE Leap to 15.0 [Thomas Bechtold]
  + net: Fix ipv6 static routes when using eni renderer
    [Raphael Glon] (LP: #1818669)
  + Add ubuntu_drivers config module [Daniel Watkins]
  + doc: Refresh Azure walinuxagent docs [Daniel Watkins]
  + tox: bump pylint version to latest (2.3.1) [Daniel Watkins]
  + DataSource: move update_events from a class to an instance attribute
    [Daniel Watkins] (LP: #1819913)
  + net/sysconfig: Handle default route setup for dhcp configured NICs
    [Robert Schweikert] (LP: #1812117)
  + DataSourceEc2: update RELEASE_BLOCKER to be more accurate
    [Daniel Watkins]
  + cloud-init-per: POSIX sh does not support string subst, use sed
    (LP: #1819222)
  + Support locking user with usermod if passwd is not available.
  + Example for Microsoft Azure data disk added. [Anton Olifir]
  + clean: correctly determine the path for excluding seed directory
    [Daniel Watkins] (LP: #1818571)
  + helpers/openstack: Treat unknown link types as physical
    [Daniel Watkins] (LP: #1639263)
  + drop Python 2.6 support and our NIH version detection [Daniel Watkins]
  + tip-pylint: Fix assignment-from-return-none errors
  + net: append type:dhcp[46] only if dhcp[46] is True in v2 netconfig
    [Kurt Stieger] (LP: #1818032)
  + cc_apt_pipelining: stop disabling pipelining by default
    [Daniel Watkins] (LP: #1794982)
  + tests: fix some slow tests and some leaking state [Daniel Watkins]
  + util: don't determine string_types ourselves [Daniel Watkins]
  + cc_rsyslog: Escape possible nested set [Daniel Watkins] (LP: #1816967)
  + Enable encrypted_data_bag_secret support for Chef
    [Eric Williams] (LP: #1817082)
  + azure: Filter list of ssh keys pulled from fabric [Jason Zions (MSFT)]
  + doc: update merging doc with fixes and some additional details/examples
  + tests: integration test failure summary to use traceback if empty error
  + This is to fix https://bugs.launchpad.net/cloud-init/+bug/1812676
    [Vitaly Kuznetsov]
  + EC2: Rewrite network config on AWS Classic instances every boot
    [Guilherme G. Piccoli] (LP: #1802073)
  + netinfo: Adjust ifconfig output parsing for FreeBSD ipv6 entries
    (LP: #1779672)
  + netplan: Don't render yaml aliases when dumping netplan (LP: #1815051)
  + add PyCharm IDE .idea/ path to .gitignore [Dominic Schlegel]
  + correct grammar issue in instance metadata documentation
    [Dominic Schlegel] (LP: #1802188)
  + clean: cloud-init clean should not trace when run from within cloud_dir
    (LP: #1795508)
  + Resolve flake8 comparison and pycodestyle over-ident issues
    [Paride Legovini]
  + opennebula: also exclude epochseconds from changed environment vars
    (LP: #1813641)
  + systemd: Render generator from template to account for system
    differences. [Robert Schweikert]
  + sysconfig: On SUSE, use STARTMODE instead of ONBOOT
    [Robert Schweikert] (LP: #1799540)
  + flake8: use ==/!= to compare str, bytes, and int literals
    [Paride Legovini]
  + opennebula: exclude EPOCHREALTIME as known bash env variable with a
    delta (LP: #1813383)
  + tox: fix disco httpretty dependencies for py37 (LP: #1813361)
  + run-container: uncomment baseurl in yum.repos.d/*.repo when using a
    proxy [Paride Legovini]
  + lxd: install zfs-linux instead of zfs meta package
    [Johnson Shi] (LP: #1799779)
  + net/sysconfig: do not write a resolv.conf file with only the header.
    [Robert Schweikert]
  + net: Make sysconfig renderer compatible with Network Manager.
    [Eduardo Otubo]
  + cc_set_passwords: Fix regex when parsing hashed passwords
    [Marlin Cremers] (LP: #1811446)
  + net: Wait for dhclient to daemonize before reading lease file
    [Jason Zions] (LP: #1794399)
  + [Azure] Increase retries when talking to Wireserver during metadata walk
    [Jason Zions]
  + Add documentation on adding a datasource.
  + doc: clean up some datasource documentation.
  + ds-identify: fix wrong variable name in ovf_vmware_transport_guestinfo.
  + Scaleway: Support ssh keys provided inside an instance tag. [PORTE Loïc]
  + OVF: simplify expected return values of transport functions.
  + Vmware: Add support for the com.vmware.guestInfo OVF transport.
    (LP: #1807466)
  + HACKING.rst: change contact info to Josh Powers
  + Update to pylint 2.2.2.
* Wed Apr 24 2019 Robert Schweikert <rjschwei@suse.com>
- Update cloud-init-write-routes.patch (bsc#1132692)
  + Properly accumulate all the defined routes for a given network device.
    Previously only the last defined route was written to the routes file.
* Sat Mar 30 2019 Robert Schweikert <rjschwei@suse.com>
- Update cloud-init-trigger-udev.patch (bsc#1125950)
  + Write the udev rules to a different file than the default
  + Settle udev if not all configured devices are in the device tree to
    avoid race condition between udev and cloud-init
* Fri Feb 22 2019 Robert Schweikert <rjschwei@suse.com>
- Add cloud-init-trigger-udev.patch (bsc#1125950)
  + When the user configures a new rules file for network devices
    the rules may not apply immediately, trigger udevadm
* Fri Feb 22 2019 Robert Schweikert <rjschwei@suse.com>
- Modify cloud-init-write-routes.patch (bsc#1125992)
  + Fix the order of calls, the SUSE implementation of route config file
    writing must clobber the default implementation.
* Fri Feb 22 2019 Robert Schweikert <rjschwei@suse.com>
- Add cloud-init-proper-ipv6-varname.patch (bsc#1126101)
  + Use the proper name to designate IPv6 addresses in ifcfg-* files
* Thu Jan 31 2019 Robert Schweikert <rjschwei@suse.com>
- Modify cloud-init-write-routes.patch (boo#1123694)
  + Drop a '-' in the route file for the last column
* Tue Jan 22 2019 Robert Schweikert <rjschwei@suse.com>
- Add cloud-init-no-empty-resolv.patch (bsc#1119397)
* Mon Jan  7 2019 Robert Schweikert <rjschwei@suse.com>
- Update to version 18.5 (bsc#1121878, boo#1116767)
  + Remove
    0001-Fix-the-service-order-for-SUSE-distributions.patch
    0001-Follow-the-ever-bouncing-ball-for-openSUSE-distribut.patch
    0002-Add-tests-for-additional-openSUSE-distro-condition-m.patch
    included upstream
  + Forward port cloud-init-sysconf-ethsetup.patch
  + Add cloud-init-write-routes.patch
  + Add cloud-init-handle-def-route-set.patch
  + tests: add Disco release [Joshua Powers]
  + net: render 'metric' values in per-subnet routes (LP: #1805871)
  + write_files: add support for appending to files. [James Baxter]
  + config: On ubuntu select cloud archive mirrors for armel, armhf, arm64.
    (LP: #1805854)
  + dhclient-hook: cleanups, tests and fix a bug on 'down' event.
  + NoCloud: Allow top level 'network' key in network-config. (LP: #1798117)
  + ovf: Fix ovf network config generation gateway/routes (LP: #1806103)
  + azure: detect vnet migration via netlink media change event
    [Tamilmani Manoharan]
  + Azure: fix copy/paste error in error handling when reading azure ovf.
  + [Adam DePue]
  + tests: fix incorrect order of mocks in test_handle_zfs_root.
  + doc: Change dns_nameserver property to dns_nameservers. [Tomer Cohen]
  + OVF: identify label iso9660 filesystems with label 'OVF ENV'.
  + logs: collect-logs ignore instance-data-sensitive.json on non-root user
    (LP: #1805201)
  + net: Ephemeral*Network: add connectivity check via URL
  + azure: _poll_imds only retry on 404. Fail on Timeout (LP: #1803598)
  + resizefs: Prefix discovered devpath with '/dev/' when path does not
    exist [Igor GaliÄ‡]
  + azure: retry imds polling on requests.Timeout (LP: #1800223)
  + azure: Accept variation in error msg from mount for ntfs volumes
    [Jason Zions] (LP: #1799338)
  + azure: fix regression introduced when persisting ephemeral dhcp lease
    [asakkurr]
  + azure: add udev rules to create cloud-init Gen2 disk name symlinks
    (LP: #1797480)
  + tests: ec2 mock missing httpretty user-data and instance-identity routes
  + azure: remove /etc/netplan/90-hotplug-azure.yaml when net from IMDS
  + azure: report ready to fabric after reprovision and reduce logging
    [asakkurr] (LP: #1799594)
  + query: better error when missing read permission on instance-data
  + instance-data: fallback to instance-data.json if sensitive is absent.
    (LP: #1798189)
  + docs: remove colon from network v1 config example. [Tomer Cohen]
  + Add cloud-id binary to packages for SUSE [Jason Zions]
  + systemd: On SUSE ensure cloud-init.service runs before wicked
    [Robert Schweikert] (LP: #1799709)
  + update detection of openSUSE variants [Robert Schweikert]
  + azure: Add apply_network_config option to disable network from IMDS
    (LP: #1798424)
  + Correct spelling in an error message (udevadm). [Katie McLaughlin]
  + tests: meta_data key changed to meta-data in ec2 instance-data.json
    (LP: #1797231)
  + tests: fix kvm integration test to assert flexible config-disk path
    (LP: #1797199)
  + tools: Add cloud-id command line utility
  + instance-data: Add standard keys platform and subplatform. Refactor ec2.
  + net: ignore nics that have "zero" mac address. (LP: #1796917)
  + tests: fix apt_configure_primary to be more flexible
  + Ubuntu: update sources.list to comment out deb-src entries. (LP: #74747)
* Fri Nov  2 2018 Robert Schweikert <rjschwei@suse.com>
- Add cloud-init-ostack-metadat-dencode.patch (bsc#1101894)
* Wed Oct 31 2018 Robert Schweikert <rjschwei@suse.com>
- Add cloud-init-static-net.patch (boo#1114160)
* Thu Oct 25 2018 Robert Schweikert <rjschwei@suse.com>
- Update to version 18.4 (bsc#1087331, bsc#1097388, boo#1111427, bsc#1095627)
  + Remove cloud-init-no-user-lock-if-already-locked.patch
    cloud-init 18.4 is not supported on SLE 11 code base
  + Remove 0001-Support-chrony-configuration-lp-1731619.patch
    Included upstream
  + Remove 0003-Distro-dependent-chrony-config-file.patch
    Included upstream
  + Remove 0001-switch-to-using-iproute2-tools.patch
    Included upstream
  + Remove cloud-init-no-python-linux-dist.patch
    Included upstream
  + Remove cloud-init-no-trace-empt-sect.patch
    Included upstream
  + Remove cloud-init-setpath-dsitentify.patch
    Included upstream
  + Modify fix-default-systemd-unit-dir.patch
    Use pkg-config, only modify the generator
  + Remove cloud-init-sysconfig-netpathfix.patch
    Fixed upstream
  + Removed cloud-init-skip-ovf-tests.patch
    Fixed upstream
  + Removed cloud-init-translate-netconf-ipv4-keep-gw.patch
    Fixed upstream
  + Add cloud-init-template-py2.patch avoid Python 3 dependency when we build
    for distros with Python 2 support
  + Add 0001-Follow-the-ever-bouncing-ball-for-openSUSE-distribut.patch
  + Add 0002-Add-tests-for-additional-openSUSE-distro-condition-m.patch
  + Add cloud-init-sysconf-path.patch
  + Add cloud-init-sysconf-ethsetup.patch
  + Add 0001-Fix-the-service-order-for-SUSE-distributions.patch
  + Add dhcp-client as requirement
    cloud-init uses dhclient to setup temporary network for
    metadata retrieval. THis is needed until lp#1733226 is addressed
  + add rtd example docs about new standardized keys
  + use ds._crawled_metadata instance attribute if set when writing
    instance-data.json
  + ec2: update crawled metadata. add standardized keys
  + tests: allow skipping an entire cloud_test without running.
  + tests: disable lxd tests on cosmic
  + cii-tests: use unittest2.SkipTest in ntp_chrony due to new deps
  + lxd: adjust to snap installed lxd.
  + docs: surface experimental doc in instance-data.json
  + tests: fix ec2 integration tests. process meta_data instead of meta-data
  + Add support for Infiniband network interfaces (IPoIB). [Mark Goddard]
  + cli: add cloud-init query subcommand to query instance metadata
  + tools/tox-venv: update for new features.
  + pylint: ignore warning assignment-from-no-return for _write_network
  + stages: Fix bug causing datasource to have incorrect sys_cfg.
    (LP: #1787459)
  + Remove dead-code _write_network distro implementations.
  + net_util: ensure static configs have netmask in translate_network result
    [Thomas Berger] (LP: #1792454)
  + Fall back to root:root on syslog permissions if other options fail.
    [Robert Schweikert]
  + tests: Add mock for util.get_hostname. [Robert Schweikert] (LP: #1792799)
  + ds-identify: doc string cleanup.
  + OpenStack: Support setting mac address on bond.
    [Fabian Wiesel] (LP: #1682064)
  + bash_completion/cloud-init: fix shell syntax error.
  + EphemeralIPv4Network: Be more explicit when adding default route.
    (LP: #1792415)
  + OpenStack: support reading of newer versions of metdata.
  + OpenStack: fix bug causing 'latest' version to be used from network.
    (LP: #1792157)
  + user-data: jinja template to render instance-data.json in cloud-config
    (LP: #1791781)
  + config: disable ssh access to a configured user account
  + tests: print failed testname instead of docstring upon failure
  + tests: Disallow use of util.subp except for where needed.
  + sysconfig: refactor sysconfig to accept distro specific templates paths
  + Add unit tests for config/cc_ssh.py [Francis Ginther]
  + Fix the built-in cloudinit/tests/helpers:skipIf
  + read-version: enhance error message [Joshua Powers]
  + hyperv_reporting_handler: simplify threaded publisher
  + VMWare: Fix a network config bug in vm with static IPv4 and no gateway.
    [Pengpeng Sun] (LP: #1766538)
  + logging: Add logging config type hyperv for reporting via Azure KVP
    [Andy Liu]
  + tests: disable other snap test as well [Joshua Powers]
  + tests: disable snap, fix write_files binary [Joshua Powers]
  + Add datasource Oracle Compute Infrastructure (OCI).
  + azure: allow azure to generate network configuration from IMDS per boot.
  + Scaleway: Add network configuration to the DataSource [Louis Bouchard]
  + docs: Fix example cloud-init analyze command to match output.
    [Wesley Gao]
  + netplan: Correctly render macaddress on a bonds and bridges when
    provided. (LP: #1784699)
  + tools: Add 'net-convert' subcommand command to 'cloud-init devel'.
  + redhat: remove ssh keys on new instance. (LP: #1781094)
  + Use typeset or local in profile.d scripts. (LP: #1784713)
  + OpenNebula: Fix null gateway6 [Akihiko Ota] (LP: #1768547)
  + oracle: fix detect_openstack to report True on OracleCloud.com DMI data
    (LP: #1784685)
  + tests: improve LXDInstance trying to workaround or catch bug.
  + update_metadata re-config on every boot comments and tests not quite
    right [Mike Gerdts]
  + tests: Collect build_info from system if available.
  + pylint: Fix pylint warnings reported in pylint 2.0.0.
  + get_linux_distro: add support for rhel via redhat-release.
  + get_linux_distro: add support for centos6 and rawhide flavors of redhat
    (LP: #1781229)
  + tools: add '--debug' to tools/net-convert.py
  + tests: bump the version of paramiko to 2.4.1.
  + docs: note in rtd about avoiding /tmp when writing files (LP: #1727876)
  + ubuntu,centos,debian: get_linux_distro to align with platform.dist
    (LP: #1780481)
  + Fix boothook docs on environment variable name (INSTANCE_I ->
    INSTANCE_ID) [Marc Tamsky]
  + update_metadata: a datasource can support network re-config every boot
  + tests: drop salt-minion integration test (LP: #1778737)
  + Retry on failed import of gpg receive keys.
  + tools: Fix run-container when neither source or binary package requested.
  + docs: Fix a small spelling error. [Oz N Tiram]
  + tox: use simplestreams from git repository rather than bzr.
- From 18.3
  + docs: represent sudo:false in docs for user_groups config module
  + Explicitly prevent `sudo` access for user module
    [Jacob Bednarz] (LP: #1771468)
  + lxd: Delete default network and detach device if lxd-init created them.
    (LP: #1776958)
  + openstack: avoid unneeded metadata probe on non-openstack platforms
    (LP: #1776701)
  + stages: fix tracebacks if a module stage is undefined or empty
    [Robert Schweikert] (LP: #1770462)
  + Be more safe on string/bytes when writing multipart user-data to disk.
    (LP: #1768600)
  + Fix get_proc_env for pids that have non-utf8 content in environment.
    (LP: #1775371)
  + tests: fix salt_minion integration test on bionic and later
  + tests: provide human-readable integration test summary when --verbose
  + tests: skip chrony integration tests on lxd running artful or older
  + test: add optional --preserve-instance arg to integraiton tests
  + netplan: fix mtu if provided by network config for all rendered types
    (LP: #1774666)
  + tests: remove pip install workarounds for pylxd, take upstream fix.
  + subp: support combine_capture argument.
  + tests: ordered tox dependencies for pylxd install
  + util: add get_linux_distro function to replace platform.dist
    [Robert Schweikert] (LP: #1745235)
  + pyflakes: fix unused variable references identified by pyflakes 2.0.0.
  + Do not use the systemd_prefix macro, not available in this environment
    [Robert Schweikert]
  + doc: Add config info to ec2, openstack and cloudstack datasource docs
  + Enable SmartOS network metadata to work with netplan via per-subnet
    routes [Dan McDonald] (LP: #1763512)
  + openstack: Allow discovery in init-local using dhclient in a sandbox.
    (LP: #1749717)
  + tests: Avoid using https in httpretty, improve HttPretty test case.
    (LP: #1771659)
  + yaml_load/schema: Add invalid line and column nums to error message
  + Azure: Ignore NTFS mount errors when checking ephemeral drive
    [Paul Meyer]
  + packages/brpm: Get proper dependencies for cmdline distro.
  + packages: Make rpm spec files patch in package version like in debs.
  + tools/run-container: replace tools/run-centos with more generic.
  + Update version.version_string to contain packaged version. (LP: #1770712)
  + cc_mounts: Do not add devices to fstab that are already present.
    [Lars Kellogg-Stedman]
  + ds-identify: ensure that we have certain tokens in PATH. (LP: #1771382)
  + tests: enable Ubuntu Cosmic in integration tests [Joshua Powers]
  + read_file_or_url: move to url_helper, fix bug in its FileResponse.
  + cloud_tests: help pylint [Ryan Harper]
  + flake8: fix flake8 errors in previous commit.
  + typos: Fix spelling mistakes in cc_mounts.py log messages [Stephen Ford]
  + tests: restructure SSH and initial connections [Joshua Powers]
  + ds-identify: recognize container-other as a container, test SmartOS.
  + cloud-config.service: run After snap.seeded.service. (LP: #1767131)
  + tests: do not rely on host /proc/cmdline in test_net.py
    [Lars Kellogg-Stedman] (LP: #1769952)
  + ds-identify: Remove dupe call to is_ds_enabled, improve debug message.
  + SmartOS: fix get_interfaces for nics that do not have addr_assign_type.
  + tests: fix package and ca_cert cloud_tests on bionic
    (LP: #1769985)
  + ds-identify: make shellcheck 0.4.6 happy with ds-identify.
  + pycodestyle: Fix deprecated string literals, move away from flake8.
  + azure: Add reported ready marker file. [Joshua Chan] (LP: #1765214)
  + tools: Support adding a release suffix through packages/bddeb.
  + FreeBSD: Invoke growfs on ufs filesystems such that it does not prompt.
    [Harm Weites] (LP: #1404745)
  + tools: Re-use the orig tarball in packages/bddeb if it is around.
  + netinfo: fix netdev_pformat when a nic does not have an address
    assigned. (LP: #1766302)
  + collect-logs: add -v flag, write to stderr, limit journal to single
    boot. (LP: #1766335)
  + IBMCloud: Disable config-drive and nocloud only if IBMCloud is enabled.
    (LP: #1766401)
  + Add reporting events and log_time around early source of blocking time
    [Ryan Harper]
  + IBMCloud: recognize provisioning environment during debug boots.
    (LP: #1767166)
  + net: detect unstable network names and trigger a settle if needed
    [Ryan Harper] (LP: #1766287)
  + IBMCloud: improve documentation in datasource.
  + sysconfig: dhcp6 subnet type should not imply dhcpv4 [Vitaly Kuznetsov]
  + packages/debian/control.in: add missing dependency on iproute2.
    (LP: #1766711)
  + DataSourceSmartOS: add locking of serial device.
    [Mike Gerdts] (LP: #1746605)
  + DataSourceSmartOS: sdc:hostname is ignored [Mike Gerdts] (LP: #1765085)
  + DataSourceSmartOS: list() should always return a list
    [Mike Gerdts] (LP: #1763480)
  + schema: in validation, raise ImportError if strict but no jsonschema.
  + set_passwords: Add newline to end of sshd config, only restart if
    updated. (LP: #1677205)
  + pylint: pay attention to unused variable warnings.
  + doc: Add documentation for AliYun datasource. [Junjie Wang]
  + Schema: do not warn on duplicate items in commands. (LP: #1764264)
  + net: Depend on iproute2's ip instead of net-tools ifconfig or route
  + DataSourceSmartOS: fix hang when metadata service is down
    [Mike Gerdts] (LP: #1667735)
  + DataSourceSmartOS: change default fs on ephemeral disk from ext3 to
    ext4. [Mike Gerdts] (LP: #1763511)
  + pycodestyle: Fix invalid escape sequences in string literals.
  + Implement bash completion script for cloud-init command line
    [Ryan Harper]
  + tools: Fix make-tarball cli tool usage for development
  + renderer: support unicode in render_from_file.
  + Implement ntp client spec with auto support for distro selection
    [Ryan Harper] (LP: #1749722)
  + Apport: add Brightbox, IBM, LXD, and OpenTelekomCloud to list of clouds.
  + tests: fix ec2 integration network metadata validation
  + tests: fix integration tests to support lxd 3.0 release
  + correct documentation to match correct attribute name usage.
    [Dominic Schlegel] (LP: #1420018)
  + cc_resizefs, util: handle no /dev/zfs [Ryan Harper]
  + doc: Fix links in OpenStack datasource documentation.
    [Dominic Schlegel] (LP: #1721660)
* Fri Aug 24 2018 rjschwei@suse.com
- Add a modified version of fix-default-systemd-unit-dir.patch
  + Removed pre-maturely, still needs 1 part of the patch
* Fri Aug 24 2018 rjschwei@suse.com
- Remove fix-default-systemd-unit-dir.patch
  + No longer needed, proper systemd config dir is queried from pckg-config
* Thu Jul  5 2018 rjschwei@suse.com
- The distribution inidcator is set to suse during template expansion,
  we do not replace anything set to ubuntu
- Do not run cloud-init after network-online, this breaks functionality in
  cloud-init. Certain parts of the code running in this phase expect to run
  before the network is on-line. This "re-introduces" boo#1097388. But the
  changes made are not generic enough.
- Root should not be enabled by default. For image builders/users that want
  root access by default they should provide an appropriate configuration
  file during image build or image setup
* Wed Jun 27 2018 bwiedemann@suse.com
- Let distribution default to opensuse/sles (boo#1099340)
- do not disable root user to make it easier to work with
- Run metadata detection after network-online (boo#1097388)
* Tue May 22 2018 rjschwei@suse.com
- Re-add generator (bsc#1089824, boo#1093501)
  + Add cloud-init-setpath-dsitentify.patch, upstream solution to
    hanle PATH issue
  + Re-enable th egenerator to reduce effort in cloud-init configuration
* Wed May 16 2018 rjschwei@suse.com
- Drop the generator (bsc#1089824, boo#1093501)
  + The generator spawns a script called ds-identify which in turn calls
    blkid. When the generator executes the environment may or may not be
    ready. The generator speeds up the boot process in cases where
    cloud-init is enabled but we are not in an environment where cloud-init
    should run -> Don't do that.
* Fri May 11 2018 rjschwei@suse.com
- Update to version 18.2 (bsc#1092637, bsc#1084509)
  + Forward port cloud-init-python2-sigpipe.patch
  + Forward port cloud-init-no-python-linux-dist.patch
  + Add cloud-init-no-trace-empt-sect.patch
  + Hetzner: Exit early if dmi system-manufacturer is not Hetzner.
  + Add missing dependency on isc-dhcp-client to trunk ubuntu packaging.
  + (LP: #1759307)
  + FreeBSD: resizefs module now able to handle zfs/zpool.
  + [Dominic Schlegel] (LP: #1721243)
  + cc_puppet: Revert regression of puppet creating ssl and ssl_cert dirs
  + Enable IBMCloud datasource in settings.py.
  + IBMCloud: Initial IBM Cloud datasource.
  + tests: remove jsonschema from xenial tox environment.
  + tests: Fix newly added schema unit tests to skip if no jsonschema.
  + ec2: Adjust ec2 datasource after exception_cb change.
  + Reduce AzurePreprovisioning HTTP timeouts.
  + [Douglas Jordan] (LP: #1752977)
  + Revert the logic of exception_cb in read_url.
  + [Kurt Garloff] (LP: #1702160, #1298921)
  + ubuntu-advantage: Add new config module to support
  + ubuntu-advantage-tools
  + Handle global dns entries in netplan (LP: #1750884)
  + Identify OpenTelekomCloud Xen as OpenStack DS.
  + [Kurt Garloff] (LP: #1756471)
  + datasources: fix DataSource subclass get_hostname method signature
  + (LP: #1757176)
  + OpenNebula: Update network to return v2 config rather than ENI.
  + [Akihiko Ota]
  + Add Hetzner Cloud DataSource
  + net: recognize iscsi root cases without ip= on kernel command line.
  + (LP: #1752391)
  + tests: fix flakes warning for unused variable
  + tests: patch leaked stderr messages from snap unit tests
  + cc_snap: Add new module to install and configure snapd and snap
  + packages.
  + tests: Make pylint happy and fix python2.6 uses of assertRaisesRegex.
  + netplan: render bridge port-priority values (LP: #1735821)
  + util: Fix subp regression. Allow specifying subp command as a string.
  + (LP: #1755965)
  + doc: fix all warnings issued by 'tox -e doc'
  + FreeBSD: Set hostname to FQDN. [Dominic Schlegel] (LP: #1753499)
  + tests: fix run_tree and bddeb
  + tests: Fix some warnings in tests that popped up with newer python.
  + set_hostname: When present in metadata, set it before network bringup.
  + (LP: #1746455)
  + tests: Centralize and re-use skipTest based on json schema presense.
  + This commit fixes get_hostname on the AzureDataSource.
  + [Douglas Jordan] (LP: #1754495)
  + shellify: raise TypeError on bad input.
  + Make salt minion module work on FreeBSD.
  + [Dominic Schlegel] (LP: #1721503)
  + Simplify some comparisions. [Rémy Léone]
  + Change some list creation and population to literal. [Rémy Léone]
  + GCE: fix reading of user-data that is not base64 encoded. (LP: #1752711)
  + doc: fix chef install from apt packages example in RTD.
  + Implement puppet 4 support [Romanos Skiadas] (LP: #1446804)
  + subp: Fix subp usage with non-ascii characters when no system locale.
  + (LP: #1751051)
  + salt: configure grains in grains file rather than in minion config.
    [Daniel Wallace]
* Wed Mar 21 2018 rjschwei@suse.com
- Update to version 18.1 (bsc#1085787, bsc#1084749)
  + Forward port cloud-init-python2-sigpipe.patch
  + Forward port 0003-Distro-dependent-chrony-config-file.patch
    partial integration into 0001-Support-chrony-configuration-lp-1731619.patch
  + Forward port cloud-init-no-python-linux-dist.patch
  + Remove 0002-Disable-method-deprecation-warning-for-pylint.patch
    use new cloud-init internal distro detection code
  + Remove cloud-init-resize-ro-btrfs.patch included upstream
  + Remove 0001-Set-syslog_fix_perms-for-SUSE-distro-addresses-bsc-1.patch
    included upstream
  + OVF: Fix VMware support for 64-bit platforms. [Sankar Tanguturi]
  + ds-identify: Fix searching for iso9660 OVF cdroms. (LP: #1749980)
  + SUSE: Fix groups used for ownership of cloud-init.log [Robert Schweikert]
  + ds-identify: check /writable/system-data/ for nocloud seed.
    (LP: #1747070)
  + tests: run nosetests in cloudinit/ directory, fix py26 fallout.
  + tools: run-centos: git clone rather than tar.
  + tests: add support for logs with lxd from snap and future lxd 3.
    (LP: #1745663)
  + EC2: Fix get_instance_id called against cached datasource pickle.
    (LP: #1748354)
  + cli: fix cloud-init status to report running when before result.json
    (LP: #1747965)
  + net: accept network-config in netplan format for renaming interfaces
    (LP: #1709715)
  + Fix ssh keys validation in ssh_util [Tatiana Kholkina]
  + docs: Update RTD content for cloud-init subcommands.
  + OVF: Extend well-known labels to include OVFENV. (LP: #1698669)
  + Fix potential cases of uninitialized variables. (LP: #1744796)
  + tests: Collect script output as binary, collect systemd journal, fix lxd.
  + HACKING.rst: mention setting user name and email via git config.
  + Azure VM Preprovisioning support. [Douglas Jordan] (LP: #1734991)
  + tools/read-version: Fix read-version when in a git worktree.
  + docs: Fix typos in docs and one debug message. [Florian Grignon]
  + btrfs: support resizing if root is mounted ro.
    [Robert Schweikert] (LP: #1734787)
  + OpenNebula: Improve network configuration support.
    [Akihiko Ota] (LP: #1719157, #1716397, #1736750)
  + tests: Fix EC2 Platform to return console output as bytes.
  + tests: Fix attempted use of /run in a test case.
  + GCE: Improvements and changes to ssh key behavior for default user.
    [Max Illfelder] (LP: #1670456, #1707033, #1707037, #1707039)
  + subp: make ProcessExecutionError have expected types in stderr, stdout.
  + tests: when querying ntp server, do not do dns resolution.
  + Recognize uppercase vfat disk labels [James Penick] (LP: #1598783)
  + tests: remove zesty as supported OS to test [Joshua Powers]
  + Do not log warning on config files that represent None. (LP: #1742479)
  + tests: Use git hash pip dependency format for pylxd.
  + tests: add integration requirements text file [Joshua Powers]
  + MAAS: add check_instance_id based off oauth tokens. (LP: #1712680)
  + tests: update apt sources list test [Joshua Powers]
  + tests: clean up image properties [Joshua Powers]
  + tests: rename test ssh keys to avoid appearance of leaking private keys.
    [Joshua Powers]
  + tests: Enable AWS EC2 Integration Testing [Joshua Powers]
  + cli: cloud-init clean handles symlinks (LP: #1741093)
  + SUSE: Add a basic test of network config rendering. [Robert Schweikert]
  + Azure: Only bounce network when necessary. (LP: #1722668)
  + lint: Fix lints seen by pylint version 1.8.1.
  + cli: Fix error in cloud-init modules --mode=init. (LP: #1736600)
* Fri Feb 16 2018 dmueller@suse.com
- update cloud-init-sysconfig-netpathfix.patch:
  * skip checking for files in /etc/sysconfig that never exist
  on a wickedd based system
* Tue Feb 13 2018 rjschwei@suse.com
- Fix logfile permission settings (bsc#1080595)
  + Add 0001-Set-syslog_fix_perms-for-SUSE-distro-addresses-bsc-1.patch
* Tue Jan 30 2018 dmueller@suse.com
- drop dependency on boto (only used in examples, and
  should really be ported to botocore/boto3 instead)
* Mon Jan 29 2018 rjschwei@suse.com
- Update to version 17.2 (boo#1069635, bsc#1072811)
  + Add cloud-init-skip-ovf-tests.patch
  + Add cloud-init-no-python-linux-dist.patch
  + Add 0001-switch-to-using-iproute2-tools.patch
  + Add 0001-Support-chrony-configuration-lp-1731619.patch
  + Add 0002-Disable-method-deprecation-warning-for-pylint.patch
  + Add 0003-Distro-dependent-chrony-config-file.patch
  + removed cloud-init-add-variant-cloudcfg.patch replaced by
    cloud-init-no-python-linux-dist.patch
  + removed zypp_add_repos.diff included upstream
  + removed zypp_add_repo_test.patch included upstream
  + removed cloud-init-hosts-template.patch included upstream
  + removed cloud-init-more-tasks.patch included upstream
  + removed cloud-init-final-no-apt.patch included upstream
  + removed cloud-init-ntp-conf-suse.patch included upstream
  + removed cloud-init-break-cycle-local-service.patch included upstream
  + removed cloud-init-reproduce-build.patch included upstream
  + For the complete changelog see https://launchpad.net/cloud-init/trunk/17.2
* Thu Jan 18 2018 gmoro@suse.com
- patch distribution detection until a fix is delivered to python3 (bsc#997614)
  add cloud-init-add-variant-cloudcfg.patch
* Tue Jan 16 2018 dimstar@opensuse.org
- Fix usage of fdupes macro: there is no '-n' parameter to the
  macro (there would be to fdupes, the command, though).
* Wed Dec  6 2017 rjschwei@suse.com
- Add cloud-init-reproduce-build.patch (boo#1069635)
  + Make builds reproducible
* Mon Nov 27 2017 kukuk@suse.de
- Add cloud-init-resize-ro-btrfs.patch
  + cc_resizefs fails if the current root is a read-only btrfs
    subvolume, use an always writeable subvolume instead [bsc#1042913]
* Sun Nov 19 2017 rjschwei@suse.com
- Add cloud-init-break-cycle-local-service.patch
  + Let systemd pull in the default targets. This breaks a cycle
* Fri Nov 17 2017 rjschwei@suse.com
- Fix variable name in cloud-init-translate-netconf-ipv4-keep-gw.patch
* Thu Nov 16 2017 rjschwei@suse.com
- Add cloud-init-translate-netconf-ipv4-keep-gw.patch (boo#1064854)
  + Properly insert the gateway information for v1 json network config data
* Sat Nov 11 2017 rjschwei@suse.com
- Add cloud-init-ntp-conf-suse.patch
  + ntp configuration was broken on sles and opensuse lp#1726572
* Wed Nov  8 2017 rjschwei@suse.com
- Add cloud-init-hosts-template.patch (bsc#1064594)
  + Properly expand the /etc/hosst file when manage_etc_hosts is set
* Thu Nov  2 2017 rjschwei@suse.com
- Fix sed expression to set distro properly (boo#1063716)
* Thu Sep 21 2017 rjschwei@suse.com
- Update to version 17.1 (bsc#1035106)
  + Version numbering scheme change now YY.NUMBER_OF_RELESE_THAT_YEAR
  + Remove cloud.cfg.suse, use generated default config file
  + Remove addopenSUSEBase.patch, included upstream
  + Remove suseIntegratedHandler.patch, included upstream
  + Remove openSUSEhostsTemplate.diff, included upstream
  + Remove cloud-init-handle-no-carrier.patch, included upstream
  + Remove cloud-init-digital-ocean-datasource.patch,
    use upstream implementation
  + Remove cloud-init-digital-ocean-datasource-enable-by-default.patch,
    use upstream implementation
  + Remove cloud-init-fix-unicode-handling-binarydecode.patch,
    included upstream
  + Remove cloud-init-no-dmidecode-on-ppc64.patch, included upstream
  + Remove dataSourceOpenNebula.patch, use upstream implementation
  + Remove setupSUSEsysVInit.diff, included upstream
  + Remove suseSysVInit.diff, included upstream
  + Remove cloud-init-finalbeforelogin.patch, don't block login
  + Remove cloud-init-handle-not-implemented-query.patch, query option removed
  + Remove cloud-init-spceandtabs-clean.patch, indentation fixed upstream
  + Remove dynamicInitCmd.diff, different solution from upstream
  + Added cloud-init-more-tasks.patch, (bsc#1047363)
    replace cloud-init-finalbeforelogin.patch
  + Forward port cloud-init-python2-sigpipe.patch
  + Remove cloud-init-net-eni.patch, included upstream
  + Remove cloud-init-service.patch, included upstream
  + Forward port cloud-init-sysconfig-netpathfix.patch
  + Remove cloud-init-net-sysconfig-lp1665441.patch, included upstream
  + Remove cloud-init-python26.patch, included upstream
  + Remove skip-argparse-on-python3.patch
  + Add cloud-init-tests-set-exec.patch
  + Add cloud-init-final-no-apt.patch
  + Add zypp_add_repo_test.patch
  + doc: document GCE datasource. [Arnd Hannemann]
  + suse: updates to templates to support openSUSE and SLES.
  + [Robert Schweikert] (LP: #1718640)
  + suse: Copy sysvinit files from redhat with slight changes.
  + [Robert Schweikert] (LP: #1718649)
  + docs: fix sphinx module schema documentation [Chad Smith]
  + tests: Add cloudinit package to all test targets [Chad Smith]
  + Makefile: No longer look for yaml files in obsolete ./bin/.
  + tests: fix ds-identify unit tests to set EC2_STRICT_ID_DEFAULT.
  + ec2: Fix maybe_perform_dhcp_discovery to use /var/tmp as a tmpdir
  + [Chad Smith] (LP: #1717627)
  + Azure: wait longer for SSH pub keys to arrive.
  + [Paul Meyer] (LP: #1717611)
  + GCE: Fix usage of user-data. (LP: #1717598)
  + cmdline: add collect-logs subcommand. [Chad Smith] (LP: #1607345)
  + CloudStack: consider dhclient lease files named with a hyphen.
  + (LP: #1717147)
  + resizefs: Drop check for read-only device file, do not warn on
  + overlayroot. [Chad Smith]
  + Do not provide systemd-fsck drop-in which could cause ordering cycles.
  + [Balint Reczey] (LP: #1717477)
  + tests: Enable the NoCloud KVM platform [Joshua Powers]
  + resizefs: pass mount point to xfs_growfs [Dusty Mabe]
  + vmware: Enable nics before sending the SUCCESS event. [Sankar Tanguturi]
  + cloud-config modules: honor distros definitions in each module
  + [Chad Smith] (LP: #1715738, #1715690)
  + chef: Add option to pin chef omnibus install version
  + [Ethan Apodaca] (LP: #1462693)
  + tests: execute: support command as string [Joshua Powers]
  + schema and docs: Add jsonschema to resizefs and bootcmd modules
  + [Chad Smith]
  + tools: Add xkvm script, wrapper around qemu-system [Joshua Powers]
  + vmware customization: return network config format
  + [Sankar Tanguturi] (LP: #1675063)
  + Ec2: only attempt to operate at local mode on known platforms.
  + (LP: #1715128)
  + Use /run/cloud-init for tempfile operations. (LP: #1707222)
  + ds-identify: Make OpenStack return maybe on arch other than intel.
  + (LP: #1715241)
  + tests: mock missed openstack metadata uri network_data.json
  + [Chad Smith] (LP: #1714376)
  + relocate tests/unittests/helpers.py to cloudinit/tests
  + [Lars Kellogg-Stedman]
  + tox: add nose timer output [Joshua Powers]
  + upstart: do not package upstart jobs, drop ubuntu-init-switch module.
  + tests: Stop leaking calls through unmocked metadata addresses
  + [Chad Smith] (LP: #1714117)
  + distro: allow distro to specify a default locale [Ryan Harper]
  + tests: fix two recently added tests for sles distro.
  + url_helper: dynamically import oauthlib import from inside oauth_headers
  + [Chad Smith]
  + tox: make xenial environment run with python3.6
  + suse: Add support for openSUSE and return SLES to a working state.
  + [Robert Schweikert]
  + GCE: Add a main to the GCE Datasource.
  + ec2: Add IPv6 dhcp support to Ec2DataSource. [Chad Smith] (LP: #1639030)
  + url_helper: fail gracefully if oauthlib is not available
  + [Lars Kellogg-Stedman] (LP: #1713760)
  + cloud-init analyze: fix issues running under python 2. [Andrew Jorgensen]
  + Configure logging module to always use UTC time.
  + [Ryan Harper] (LP: #1713158)
  + Log a helpful message if a user script does not include shebang.
  + [Andrew Jorgensen]
  + cli: Fix command line parsing of coniditionally loaded subcommands.
  + [Chad Smith] (LP: #1712676)
  + doc: Explain error behavior in user data include file format.
  + [Jason Butz]
  + cc_landscape & cc_puppet: Fix six.StringIO use in writing configs
  + [Chad Smith] (LP: #1699282, #1710932)
  + schema cli: Add schema subcommand to cloud-init cli and cc_runcmd schema
  + [Chad Smith]
  + Debian: Remove non-free repositories from apt sources template.
  + [Joonas Kylmälä] (LP: #1700091)
  + tools: Add tooling for basic cloud-init performance analysis.
  + [Chad Smith] (LP: #1709761)
  + network: add v2 passthrough and fix parsing v2 config with bonds/bridge
  + params [Ryan Harper] (LP: #1709180)
  + doc: update capabilities with features available, link doc reference,
  + cli example [Ryan Harper]
  + vcloud directory: Guest Customization support for passwords
  + [Maitreyee Saikia]
  + ec2: Allow Ec2 to run in init-local using dhclient in a sandbox.
  + [Chad Smith] (LP: #1709772)
  + cc_ntp: fallback on timesyncd configuration if ntp is not installable
  + [Ryan Harper] (LP: #1686485)
  + net: Reduce duplicate code. Have get_interfaces_by_mac use
  + get_interfaces.
  + tests: Fix build tree integration tests [Joshua Powers]
  + sysconfig: Dont repeat header when rendering resolv.conf
  + [Ryan Harper] (LP: #1701420)
  + archlinux: Fix bug with empty dns, do not render 'lo' devices.
  + (LP: #1663045, #1706593)
  + cloudinit.net: add initialize_network_device function and tests
  + [Chad Smith]
  + makefile: fix ci-deps-ubuntu target [Chad Smith]
  + tests: adjust locale integration test to parse default locale.
  + tests: remove 'yakkety' from releases as it is EOL.
  + tests: Add initial tests for EC2 and improve a docstring.
  + locale: Do not re-run locale-gen if provided locale is system default.
  + archlinux: fix set hostname usage of write_file.
  + [Joshua Powers] (LP: #1705306)
  + sysconfig: support subnet type of 'manual'.
  + tools/run-centos: make running with no argument show help.
  + Drop rand_str() usage in DNS redirection detection
  + [Bob Aman] (LP: #1088611)
  + sysconfig: use MACADDR on bonds/bridges to configure mac_address
  + [Ryan Harper] (LP: #1701417)
  + net: eni route rendering missed ipv6 default route config
  + [Ryan Harper] (LP: #1701097)
  + sysconfig: enable mtu set per subnet, including ipv6 mtu
  + [Ryan Harper] (LP: #1702513)
  + sysconfig: handle manual type subnets [Ryan Harper] (LP: #1687725)
  + sysconfig: fix ipv6 gateway routes [Ryan Harper] (LP: #1694801)
  + sysconfig: fix rendering of bond, bridge and vlan types.
  + [Ryan Harper] (LP: #1695092)
  + Templatize systemd unit files for cross distro deltas. [Ryan Harper]
  + sysconfig: ipv6 and default gateway fixes. [Ryan Harper] (LP: #1704872)
  + net: fix renaming of nics to support mac addresses written in upper
  + case. (LP: #1705147)
  + tests: fixes for issues uncovered when moving to python 3.6.
  + (LP: #1703697)
  + sysconfig: include GATEWAY value if set in subnet
  + [Ryan Harper] (LP: #1686856)
  + Scaleway: add datasource with user and vendor data for Scaleway.
  + [Julien Castets]
  + Support comments in content read by load_shell_content.
  + cloudinitlocal fail to run during boot [Hongjiang Zhang]
  + doc: fix disk setup example table_type options
  + [Sandor Zeestraten] (LP: #1703789)
  + tools: Fix exception handling. [Joonas Kylmälä] (LP: #1701527)
  + tests: fix usage of mock in GCE test.
  + test_gce: Fix invalid mock of platform_reports_gce to return False
  + [Chad Smith]
  + test: fix incorrect keyid for apt repository.
  + [Joshua Powers] (LP: #1702717)
  + tests: Update version of pylxd [Joshua Powers]
  + write_files: Remove log from helper function signatures.
  + [Andrew Jorgensen]
  + doc: document the cmdline options to NoCloud [Brian Candler]
  + read_dmi_data: always return None when inside a container. (LP: #1701325)
  + requirements.txt: remove trailing white space.
  + Azure: Add network-config, Refactor net layer to handle duplicate macs.
  + [Ryan Harper]
  + Tests: Simplify the check on ssh-import-id [Joshua Powers]
  + tests: update ntp tests after sntp added [Joshua Powers]
  + FreeBSD: Make freebsd a variant, fix unittests and
  + tools/build-on-freebsd.
  + FreeBSD: fix test failure
  + FreeBSD: replace ifdown/ifup with "ifconfig down" and "ifconfig up".
  + [Hongjiang Zhang] (LP: #1697815)
  + FreeBSD: fix cdrom mounting failure if /mnt/cdrom/secure did not exist.
  + [Hongjiang Zhang] (LP: #1696295)
  + main: Don't use templater to format the welcome message
  + [Andrew Jorgensen]
  + docs: Automatically generate module docs form schema if present.
  + [Chad Smith]
  + debian: fix path comment in /etc/hosts template.
  + [Jens Sandmann] (LP: #1606406)
  + suse: add hostname and fully qualified domain to template.
  + [Jens Sandmann]
  + write_file(s): Print permissions as octal, not decimal [Andrew Jorgensen]
  + ci deps: Add --test-distro to read-dependencies to install all deps
  + [Chad Smith]
  + tools/run-centos: cleanups and move to using read-dependencies
  + pkg build ci: Add make ci-deps-<distro> target to install pkgs
  + [Chad Smith]
  + systemd: make cloud-final.service run before apt daily services.
  + (LP: #1693361)
  + selinux: Allow restorecon to be non-fatal. [Ryan Harper] (LP: #1686751)
  + net: Allow netinfo subprocesses to return 0 or 1.
  + [Ryan Harper] (LP: #1686751)
  + net: Allow for NetworkManager configuration [Ryan McCabe] (LP: #1693251)
  + Use distro release version to determine if we use systemd in redhat spec
  + [Ryan Harper]
  + net: normalize data in network_state object
  + Integration Testing: tox env, pyxld 2.2.3, and revamp framework
  + [Wesley Wiedenmeier]
  + Chef: Update omnibus url to chef.io, minor doc changes. [JJ Asghar]
  + tools: add centos scripts to build and test [Joshua Powers]
  + Drop cheetah python module as it is not needed by trunk [Ryan Harper]
  + rhel/centos spec cleanups.
  + cloud.cfg: move to a template.  setup.py changes along the way.
  + Makefile: add deb-src and srpm targets. use PYVER more places.
  + makefile: fix python 2/3 detection in the Makefile [Chad Smith]
  + snap: Removing snapcraft plug line [Joshua Powers] (LP: #1695333)
  + RHEL/CentOS: Fix default routes for IPv4/IPv6 configuration.
  + [Andreas Karis] (LP: #1696176)
  + test: Fix pyflakes complaint of unused import.
  + [Joshua Powers] (LP: #1695918)
  + NoCloud: support seed of nocloud from smbios information
  + [Vladimir Pouzanov] (LP: #1691772)
  + net: when selecting a network device, use natural sort order
  + [Marc-Aurèle Brothier]
  + fix typos and remove whitespace in various docs [Stephan Telling]
  + systemd: Fix typo in comment in cloud-init.target. [Chen-Han Hsiao]
  + Tests: Skip jsonschema related unit tests when dependency is absent.
  + [Chad Smith] (LP: #1695318)
  + azure: remove accidental duplicate line in merge.
  + azure: identify platform by well known value in chassis asset tag.
  + [Chad Smith] (LP: #1693939)
  + tools/net-convert.py: support old cloudinit versions by using kwargs.
  + ntp: Add schema definition and passive schema validation.
  + [Chad Smith] (LP: #1692916)
  + Fix eni rendering for bridge params that require repeated key for
  + values. [Ryan Harper]
  + net: remove systemd link file writing from eni renderer [Ryan Harper]
  + AliYun: Enable platform identification and enable by default.
  + [Junjie Wang] (LP: #1638931)
  + net: fix reading and rendering addresses in cidr format.
  + [Dimitri John Ledkov] (LP: #1689346, #1684349)
  + disk_setup: udev settle before attempting partitioning or fs creation.
  + (LP: #1692093)
  + GCE: Update the attribute used to find instance SSH keys.
  + [Daniel Watkins] (LP: #1693582)
  + nplan: For bonds, allow dashed or underscore names of keys.
  + [Dimitri John Ledkov] (LP: #1690480)
  + python2.6: fix unit tests usage of assertNone and format.
  + test: update docstring on test_configured_list_with_none
  + fix tools/ds-identify to not write None twice.
  + tox/build: do not package depend on style requirements.
  + cc_ntp: Restructure cc_ntp unit tests. [Chad Smith] (LP: #1692794)
  + flake8: move the pinned version of flake8 up to 3.3.0
  + tests: Apply workaround for snapd bug in test case. [Joshua Powers]
  + RHEL/CentOS: Fix dual stack IPv4/IPv6 configuration.
  + [Andreas Karis] (LP: #1679817, #1685534, #1685532)
  + disk_setup: fix several issues with gpt disk partitions. (LP: #1692087)
  + function spelling & docstring update [Joshua Powers]
  + Fixing wrong file name regression. [Joshua Powers]
  + tox: move pylint target to 1.7.1
  + Fix get_interfaces_by_mac for empty macs (LP: #1692028)
  + DigitalOcean: remove routes except for the public interface.
  + [Ben Howard] (LP: #1681531.)
  + netplan: pass macaddress, when specified, for vlans
  + [Dimitri John Ledkov] (LP: #1690388)
  + doc: various improvements for the docs on cc_users_groups.
  + [Felix Dreissig]
  + cc_ntp: write template before installing and add service restart
  + [Ryan Harper] (LP: #1645644)
  + cloudstack: fix tests to avoid accessing /var/lib/NetworkManager
  + [Lars Kellogg-Stedman]
  + tests: fix hardcoded path to mkfs.ext4 [Joshua Powers] (LP: #1691517)
  + Actually skip warnings when .skip file is present.
  + [Chris Brinker] (LP: #1691551)
  + netplan: fix netplan render_network_state signature.
  + [Dimitri John Ledkov] (LP: #1685944)
  + Azure: fix reformatting of ephemeral disks on resize to large types.
  + (LP: #1686514)
  + Revert "tools/net-convert: fix argument order for render_network_state"
  + make deb: Add devscripts dependency for make deb. Cleanup
  + packages/bddeb. [Chad Smith] (LP: #1685935)
  + tools/net-convert: fix argument order for render_network_state
  + [Ryan Harper] (LP: #1685944)
  + openstack: fix log message copy/paste typo in _get_url_settings
  + [Lars Kellogg-Stedman]
  + unittests: fix unittests run on centos [Joshua Powers]
  + Improve detection of snappy to include os-release and kernel cmdline.
  + (LP: #1689944)
  + Add address to config entry generated by _klibc_to_config_entry.
  + [Julien Castets] (LP: #1691135)
  + sysconfig: Raise ValueError when multiple default gateways are present.
  + [Chad Smith] (LP: #1687485)
  + FreeBSD: improvements and fixes for use on Azure
  + [Hongjiang Zhang] (LP: #1636345)
  + Add unit tests for ds-identify, fix Ec2 bug found.
  + fs_setup: if cmd is specified, use shell interpretation.
  + [Paul Meyer] (LP: #1687712)
  + doc: document network configuration defaults policy and formats.
  + [Ryan Harper]
  + Fix name of "uri" key in docs for "cc_apt_configure" module
  + [Felix Dreissig]
  + tests: Enable artful [Joshua Powers]
  + nova-lxd: read product_name from environment, not platform.
  + (LP: #1685810)
  + Fix yum repo config where keys contain array values
  + [Dylan Perry] (LP: #1592150)
  + template: Update debian backports template [Joshua Powers] (LP: #1627293)
  + rsyslog: replace ~ with stop [Joshua Powers] (LP: #1367899)
  + Doc: add additional RTD examples [Joshua Powers] (LP: #1459604)
  + Fix growpart for some cases when booted with root=PARTUUID.
  + (LP: #1684869)
  + pylint: update output style to parseable [Joshua Powers]
  + pylint: fix all logging warnings [Joshua Powers]
  + CloudStack: Add NetworkManager to list of supported DHCP lease dirs.
  + [Syed]
  + net: kernel lies about vlans not stealing mac addresses, when they do
  + [Dimitri John Ledkov] (LP: #1682871)
  + ds-identify: Check correct path for "latest" config drive
  + [Daniel Watkins] (LP: #1673637)
  + doc: Fix example for resolve.conf configuration.
  + [Jon Grimm] (LP: #1531582)
  + Fix examples that reference upstream chef repository.
  + [Jon Grimm] (LP: #1678145)
  + doc: correct grammar and improve clarity in merging documentation.
  + [David Tagatac]
  + doc: Add missing doc link to snap-config module. [Ryan Harper]
  + snap: allows for creating cloud-init snap [Joshua Powers]
  + DigitalOcean: assign IPv4ll address to lowest indexed interface.
  + [Ben Howard]
  + DigitalOcean: configure all NICs presented in meta-data. [Ben Howard]
  + Remove (and/or fix) URL shortener references [Jon Grimm] (LP: #1669727)
  + HACKING.rst: more info on filling out contributors agreement.
  + util: teach write_file about copy_mode option
  + [Lars Kellogg-Stedman] (LP: #1644064)
  + DigitalOcean: bind resolvers to loopback interface. [Ben Howard]
  + tests: fix AltCloud tests to not rely on blkid (LP: #1636531)
  + OpenStack: add 'dvs' to the list of physical link types. (LP: #1674946)
  + Fix bug that resulted in an attempt to rename bonds or vlans.
  + (LP: #1669860)
  + tests: update OpenNebula and Digital Ocean to not rely on host
  + interfaces.
  + net: in netplan renderer delete known image-builtin content.
  + (LP: #1675576)
  + doc: correct grammar in capabilities.rst [David Tagatac]
  + ds-identify: fix detecting of maas datasource. (LP: #1677710)
  + netplan: remove debugging prints, add debug logging [Ryan Harper]
  + ds-identify: do not write None twice to datasource_list.
  + support resizing partition and rootfs on system booted without
  + initramfs. [Steve Langasek] (LP: #1677376)
  + apt_configure: run only when needed. (LP: #1675185)
  + OpenStack: identify OpenStack by product 'OpenStack Compute'.
  + (LP: #1675349)
  + GCE: Search GCE in ds-identify, consider serial number in check.
  + (LP: #1674861)
  + Add support for setting hashed passwords [Tore S. Lonoy] (LP: #1570325)
  + Fix filesystem creation when using "partition: auto"
  + [Jonathan Ballet] (LP: #1634678)
  + ConfigDrive: support reading config drive data from /config-drive.
  + (LP: #1673411)
  + ds-identify: fix detection of Bigstep datasource. (LP: #1674766)
  + test: add running of pylint [Joshua Powers]
  + ds-identify: fix bug where filename expansion was left on.
  + advertise network config v2 support (NETWORK_CONFIG_V2) in features.
  + Bigstep: fix bug when executing in python3. [root]
  + Fix unit test when running in a system deployed with cloud-init.
  + Bounce network interface for Azure when using the built-in path.
  + [Brent Baude] (LP: #1674685)
  + cloudinit.net: add network config v2 parsing and rendering [Ryan Harper]
  + net: Fix incorrect call to isfile [Joshua Powers] (LP: #1674317)
  + net: add renderers for automatically selecting the renderer.
  + doc: fix config drive doc with regard to unpartitioned disks.
  + (LP: #1673818)
  + test: Adding integratiron test for password as list [Joshua Powers]
  + render_network_state: switch arguments around, do not require target
  + support 'loopback' as a device type.
  + Integration Testing: improve testcase subclassing [Wesley Wiedenmeier]
  + gitignore: adding doc/rtd_html [Joshua Powers]
  + doc: add instructions for running integration tests via tox.
  + [Joshua Powers]
  + test: avoid differences in 'date' output due to daylight savings.
  + Fix chef config module in omnibus install. [Jeremy Melvin] (LP: #1583837)
  + Add feature flags to cloudinit.version. [Wesley Wiedenmeier]
  + tox: add a citest environment
  + Further fix regression to support 'password' for default user.
  + fix regression when no chpasswd/list was provided.
  + Support chpasswd/list being a list in addition to a string.
  + [Sergio Lystopad] (LP: #1665694)
  + doc: Fix configuration example for cc_set_passwords module.
  + [Sergio Lystopad] (LP: #1665773)
  + net: support both ipv4 and ipv6 gateways in sysconfig.
  + [Lars Kellogg-Stedman] (LP: #1669504)
  + net: do not raise exception for > 3 nameservers
  + [Lars Kellogg-Stedman] (LP: #1670052)
  + ds-identify: report cleanups for config and exit value. (LP: #1669949)
  + ds-identify: move default setting for Ec2/strict_id to a global.
  + ds-identify: record not found in cloud.cfg and always add None.
  + Support warning if the used datasource is not in ds-identify's list.
  + tools/ds-identify: make report mode write namespaced results.
  + Move warning functionality to cloudinit/warnings.py
  + Add profile.d script for showing warnings on login.
  + Z99-cloud-locale-test.sh: install and make consistent.
  + tools/ds-identify: look at cloud.cfg when looking for ec2 strict_id.
  + tools/ds-identify: disable vmware_guest_customization by default.
  + tools/ds-identify: ovf identify vmware guest customization.
  + Identify Brightbox as an Ec2 datasource user. (LP: #1661693)
  + DatasourceEc2: add warning message when not on AWS.
  + ds-identify: add reading of datasource/Ec2/strict_id
  + tools/ds-identify: add support for found or maybe contributing config.
  + tools/ds-identify: read the seed directory on Ec2
  + tools/ds-identify: use quotes in local declarations.
  + tools/ds-identify: fix documentation of policy setting in a comment.
  + ds-identify: only run once per boot unless --force is given.
  + flake8: fix flake8 complaints in previous commit.
  + net: correct errors in cloudinit/net/sysconfig.py
  + [Lars Kellogg-Stedman] (LP: #1665441)
  + ec2_utils: fix MetadataLeafDecoder that returned bytes on empty
  + apply the runtime configuration written by ds-identify.
  + ds-identify: fix checking for filesystem label (LP: #1663735)
  + ds-identify: read ds=nocloud properly (LP: #1663723)
  + support nova-lxd by reading platform from environment of pid 1.
  + (LP: #1661797)
  + ds-identify: change aarch64 to use the default for non-dmi systems.
  + Remove style checking during build and add latest style checks to tox
  + [Joshua Powers] (LP: #1652329)
  + code-style: make master pass pycodestyle (2.3.1) cleanly, currently:
  + [Joshua Powers]
  + manual_cache_clean: When manually cleaning touch a file in instance dir.
  + Add tools/ds-identify to identify datasources available.
  + Fix small typo and change iso-filename for consistency [Robin Naundorf]
  + Fix eni rendering of multiple IPs per interface
  + [Ryan Harper] (LP: #1657940)
  + tools/mock-meta: support python2 or python3 and ipv6 in both.
  + tests: remove executable bit on test_net, so it runs, and fix it.
  + tests: No longer monkey patch httpretty for python 3.4.2
  + Add 3 ecdsa-sha2-nistp* ssh key types now that they are standardized
  + [Lars Kellogg-Stedman] (LP: #1658174)
  + reset httppretty for each test [Lars Kellogg-Stedman] (LP: #1658200)
  + build: fix running Make on a branch with tags other than master
  + EC2: Do not cache security credentials on disk
  + [Andrew Jorgensen] (LP: #1638312)
  + doc: Fix typos and clarify some aspects of the part-handler
  + [Erik M. Bray]
  + doc: add some documentation on OpenStack datasource.
  + OpenStack: Use timeout and retries from config in get_data.
  + [Lars Kellogg-Stedman] (LP: #1657130)
  + Fixed Misc issues related to VMware customization. [Sankar Tanguturi]
  + Fix minor docs typo: perserve > preserve [Jeremy Bicha]
  + Use dnf instead of yum when available
  + [Lars Kellogg-Stedman] (LP: #1647118)
  + validate-yaml: use python rather than explicitly python3
  + Get early logging logged, including failures of cmdline url.
- From 0.7.9
  + doc: adjust headers in tests documentation for consistency.
  + pep8: fix issue found in zesty build with pycodestyle.
  + integration test: initial commit of integration test framework
  + [Wesley Wiedenmeier]
  + LICENSE: Allow dual licensing GPL-3 or Apache 2.0 [Jon Grimm]
  + Fix config order of precedence, putting kernel command line over system.
  + [Wesley Wiedenmeier] (LP: #1582323)
  + pep8: whitespace fix
  + Update the list of valid ssh keys. [Michael Felt]
  + network: add ENI unit test for statically rendered routes.
  + set_hostname: avoid erroneously appending domain to fqdn
  + [Lars Kellogg-Stedman] (LP: #1647910)
  + doc: change 'nobootwait' to 'nofail' in docs [Anhad Jai Singh]
  + Replace an expired bit.ly link in code comment.
  + user-groups: fix bug when groups was provided as string and had spaces
  + (LP: #1354694)
  + mounts: use mount -a again to accomplish mounts (LP: #1647708)
  + CloudSigma: Fix bug where datasource was not loaded in local search.
  + (LP: #1648380)
  + when adding a user, strip whitespace from group list [Lars Kellogg-Stedman]
  + (LP: #1354694)
  + fix decoding of utf-8 chars in yaml test
  + Replace usage of sys_netdev_info with read_sys_net (LP: #1625766)
  + fix problems found in python2.6 test.
  + OpenStack: extend physical types to include hyperv, hw_veb, vhost_user.
  + (LP: #1642679)
  + tests: fix assumptions that expected no eth0 in system. (LP: #1644043)
  + net/cmdline: Consider ip= or ip6= on command line not only ip=
  + (LP: #1639930)
  + Just use file logging by default (LP: #1643990)
  + Improve formatting for ProcessExecutionError [Wesley Wiedenmeier]
  + flake8: fix trailing white space
  + Doc: various documentation fixes [Sean Bright]
  + cloudinit/config/cc_rh_subscription.py: Remove repos before adding
  + [Brent Baude]
  + packages/redhat: fix rpm spec file.
  + main: set TZ in environment if not already set. [Ryan Harper]
  + Azure: No longer rely on walinux agent. (LP: #1538522)
  + disk_setup: Use sectors as unit when formatting MBR disks with sfdisk.
  + [Daniel Watkins] (LP: #1460715)
  + Add activate_datasource, for datasource specific code paths. (LP: #1611074)
  + systemd: cloud-init-local use RequiresMountsFor=/var/lib/cloud
  + (LP: #1642062)
  + systemd: cloud-init remove After=systemd-networkd-wait-online
  + systemd: cloud-init-local change Before basic to sysinit
  + pep8: fix style errors reported by pycodestyle 2.1.0
  + systemd: drop both Wants and After local-fs.target
  + systemd: networking service adjustments. (LP: #1636912)
  + systemd: replace Before=basic.target, dbus.target with sysinit.target
  + (LP: #1629797)
  + doc: Add documentation on stages of boot.
  + doc: make the RST files consistently formated and other improvements.
  + Ec2: fix syntax and tox in previous commit.
  + Ec2: protect against non-dictionary in block-device-mapping.
  + doc: fixed example to not overwrite /etc/hosts [Chris Glass]
  + Doc: fix spelling / typos in ca_certs and scripts_vendor.
  + pyflakes: fix issue with pyflakes 1.3 found in ubuntu zesty-proposed.
  + net/cmdline: Further adjustments to ipv6 support [LaMont Jones]
  + (LP: #1621615)
  + Add coverage dependency to bddeb to fix package build.
  + doc: improve HACKING.rst file
  + dmidecode: Allow dmidecode to be used on aarch64 [Robert Schweikert]
  + AliYun: Add new datasource for Ali-Cloud ECS [kaihuan.pkh]
  + Add coverage collection to tox unit tests. [Joshua Powers]
  + cc_users_groups: fix remaing call to ds.normalize_user_groups [Ryan Harper]
  + disk-config: udev settle after partitioning in gpt format. (LP: #1626243)
  + unittests: do not read system /etc/cloud/cloud.cfg.d (LP: #1635350)
  + Add documentation for logging features. [Wesley Wiedenmeier]
  + Add support for snap create-user on Ubuntu Core images. [Ryan Harper]
  + Fix sshd restarts for rhel distros. [Jim Gorz]
  + OpenNebula: replace 'ip' parsing with cloudinit.net usage.
  + Fix python2.6 things found running in centos 6.
  + Move user/group functions to new ug_util file
  + DigitalOcean: enable usage of data source by default.
  + update Gentoo initscripts to run in the correct order [Matthew Thode]
  + MAAS: improve the main of datasource to look at kernel cmdline config.
  + tests: silence the Cheetah UserWarning about NameMapper C version.
  + systemd: Run cloud-init.service Before dbus.socket not dbus.target
  + [Daniel Watkins] (LP: #1629797)
  + systemd: run cloud-init.service Before dbus.service (LP: #1629797)
  + unittests: fix use of mock 2.0 'assert_called' when running make check
  + [Ryan Harper]
  + Improve module documentation and doc cleanup. [Wesley Wiedenmeier]
  + lxd: Update network config for LXD 2.3 [Stéphane Graber]
  + DigitalOcean: use meta-data for network configruation [Ben Howard]
  + ntp: move to run after apt configuration (LP: #1628337)
  + Decode unicode types in decode_binary [Robert Schweikert]
  + systemd: Ensure that cloud-init-local happens before NetworkManager
  + Allow ephemeral drive to be unpartitioned [Paul Meyer]
  + subp: add 'update_env' argument
  + net: support reading ipv6 dhcp config from initramfs [LaMont Jones]
  + (LP: #1621615, #1621507)
  + Adjust mounts and disk configuration for systemd. (LP: #1611074)
  + dmidecode: run dmidecode only on i?86 or x86_64 arch. [Robert Schweikert]
  + systemd: put cloud-init.target After multi-user.target (LP: #1623868)
* Wed Sep 20 2017 dmueller@suse.com
- add skip-argparse-on-python3.patch: don't depend on argparse
  for python3, it is builtin there (as of python 3.2, so the
  patch should be good enough)
* Mon Sep 18 2017 kukuk@suse.de
- python_sitelib does not seem to exist for non single-spec
  python modules, use python2_sitelib and python3_sitelib instead.
* Mon Sep 11 2017 rjschwei@suse.com
- Drop python-cheetah as requirement
  + Cheetah is no maintained and cloud-init switches to Jinja2 as
    templating engine if Cheetah is not available
- Drop argparse as dependency for Py3 build
  + argparse is built into Python
* Fri Aug 25 2017 rjschwei@suse.com
- Modify cloud-init-finalbeforelogin.patch (bsc#1047363)
  + Support user processes running in coud-init-final to consume a
    large number of threads.
- Modify cloud-init-service.patch (bsc#1055649)
  + Start after dbus.service, needed by hotnamectl
- Modify cloud-init-handle-not-implemented-query.patch
  + print needs () for Python3
- Add cloud-init-spceandtabs-clean.patch
  + Fix inconsistent use of spaces and tabs in various files
- Modify suseIntegratedHandler.patch
  + Fix mode setting passed to function for file writing
- Set packag up to build with Python 3 for distros later than SLE 12
* Sat Mar 11 2017 kukuk@suse.de
- On Tumbleweed we need net-tools-deprecated to setup the network
* Mon Feb 27 2017 dmueller@suse.com
- add cloud-init-net-sysconfig-lp1665441.patch (lp#1665441)
* Mon Feb 20 2017 kukuk@suse.de
- Don't call insserv if we use systemd
* Thu Feb 16 2017 rjschwei@suse.com
- Do not set mount options for ephemeral drive, use the defaults
  that are built into the code (bsc#930524)
* Thu Feb 16 2017 rjschwei@suse.com
- Update fix-default-systemd-unit-dir.patch (bsc#1024709)
  + based on work by Thomas Abraham
- Add cloud-init-handle-not-implemented-query.patch (boo#1017832)
* Mon Jan 23 2017 kukuk@suse.de
- Require net-tools for network setup
* Sat Dec 17 2016 rjschwei@suse.com
- Configuration split (bsc#1016160)
* Tue Dec 13 2016 kukuk@suse.de
- fix syntax error in datasource LocalDisk (fix got somehow lost)
* Mon Dec 12 2016 dmueller@suse.com
- adjust license (as of 0.7.8 AGPL-3.0 was added)
* Mon Dec 12 2016 dmueller@suse.com
- fix unintentional edit in last change again
* Fri Dec  9 2016 jgleissner@suse.com
- Modify suseIntegratedHandler.patch (bsc#998103)
  + Store previous hostname so update_hostname module does not
    overwrite manually set hostnames
- cloud-init-python26.patch
  + Compatibility fixes with Python 2.6
* Thu Dec  8 2016 dmueller@suse.com
- fix the cloud.cfg split, cyclic non-versioned dependencies are
  bad. also fix changelog entries
* Thu Dec  1 2016 kukuk@suse.de
- add datasourceLocalDisk.patch:
  * Fix datasourceLocalDisk module in case directory exists but is
  empty.
* Wed Nov 30 2016 kukuk@suse.com
- Add Conflicts for otherproviders of cloud-init-config.
- Add require for python-six (used by several modules)
* Mon Nov 28 2016 kukuk@suse.com
- Add LocalDisk datasource datasourceLocalDisk.patch [FATE#321107]
* Wed Nov 23 2016 kukuk@suse.de
- Reworked zypp_add_repos.diff to behave similar to zypper ar
* Tue Nov 22 2016 kukuk@suse.de
- Move cloud.cfg into an own sub-package, so that we can have
  a product specific version. [FATE#322039]
* Sun Nov 13 2016 kukuk@suse.de
- Add zypp_add_repos.diff to support repos for zypper [FATE#322038]
* Tue Nov  1 2016 rjschwei@suse.com
- Modify suseIntegratedHandler.patch (bsc#1007529)
  + Fall back to the previous method of writing network information
    We have to work out upstream how to have distro specific renderer
    for sysconfig
* Mon Oct 31 2016 rjschwei@suse.com
- Add cloud-init-sysconfig-netpathfix.patch (bsc#1007529)
  + Fix the default path for network scripts
- Cosmetic changes to suseIntegratedHandler.patch
* Sat Oct 29 2016 rjschwei@suse.com
- Update cloud-init-no-dmidecode-on-ppc64.patch (bsc#1005616)
  + aarch64 does support dmidecode
* Sat Oct 29 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + Break another cycle this one in -final
* Fri Oct 28 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + Better match upstream intend Ubuntu networking.service is equivalent
    to SUSE wicked, thus we cannot translate networking to network, but need
    to translate it to wicked
* Fri Oct 28 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + We need the following order:
  - something brings networking fully up (in our case wicked)
  - cloud-init.service runs
  - network-online.target is reached
* Fri Oct 28 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + The network must be up an running in order to get ssh key injected
* Fri Oct 28 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + Had self reference and thus cloud-init.service was never executed
    which caused ssh key loading failure
* Fri Oct 28 2016 bwiedemann@suse.com
- Do not own /lib/udev to not conflict with udev rpm
* Thu Oct 27 2016 rjschwei@suse.com
- Forward port suseIntegratedHandler.patch
  + Implement new abstract interfaces
  + Some minor implementation fixes
* Wed Oct 26 2016 rjschwei@suse.com
- Appease the build service, differences between OBS and IBS,
  and own the directories
* Wed Oct 26 2016 rjschwei@suse.com
- Fix package, udev rules should be in /usr for distros after
  SLES 11
* Wed Oct 19 2016 dmueller@suse.com
- add cloud-init-digital-ocean-datasource-enable-by-default.patch,
  cloud-init-digital-ocean-datasource.patch: add DigitalOcean support
- run tests on build
* Tue Oct 11 2016 rjschwei@suse.com
- Add cloud-init-handle-no-carrier.patch (boo#1003977)
  - Handle the exception when attempting to detect if the network
    device is up when it is not
* Mon Oct 10 2016 rjschwei@suse.com
- Update cloud-init-service.patch (boo#999942)
  - Backport upstream commits 3705bb5964a and 6e45ffb21e96
* Thu Sep 15 2016 rjschwei@suse.com
- Decoding error (boo#998843)
  + Added cloud-init-fix-unicode-handling-binarydecode.patch
- Fix dependencies, depends on oauthlib instead of oauth
* Wed Sep 14 2016 rjschwei@suse.com
- Fix dataSourceOpenNebula.patch, missing closing paren (boo#998836)
* Wed Sep 14 2016 rjschwei@suse.com
- Fix typo in cloud-init-service.patch
* Tue Sep 13 2016 rjschwei@suse.com
- update to version 0.7.8 (bsc#998103)
  + added cloud-init-net-eni.patch based on work by eblock
  - Using config-drive instead of metadata failed because the network
    translation to Ubuntu-style did not return gateway information to
    opensuse.py
  + added cloud-init-service.patch based on work by eblock
  - The service file cloud-init.service referenced networking.service
    which on SUSE is network.service
  + remove no_logic_change.patch included in updated upstream source
  + forward port suseIntegratedHandler.patch
  + forward port setupSUSEsysVInit.diff
  + forward port cloud-init-no-dmidecode-on-ppc64.patch
  + foward port dataSourceOpenNebula.patch
  + forward port fix-default-systemd-unit-dir.patch
  + forward port cloud-init-finalbeforelogin.patch
  + forward port cloud-init-python2-sigpipe.patch
  + SmartOS: more improvements for network configuration
  + add ntp config module [Ryan Harper]
  + ChangeLog: update changelog for previous commit.
  + Add distro tags on config modules that should have it.
  + NoCloud: fix bug providing network-interfaces via meta-data. (LP: 1577982)
  + ConfigDrive: recognize 'tap' as a link type. (LP: #1610784)
  + Upgrade to a configobj package new enough to work
  + MAAS: add vendor-data support (LP: #1612313)
  + DigitalOcean: use the v1.json endpoint [Ben Howard]
  + Get Azure endpoint server from DHCP client [Brent Baude]
  + Apt: add new apt configuration format [Christian Ehrhardt]
  + distros: fix get_primary_arch method use of os.uname [Andrew Jorgensen]
  + Fix Gentoo net config generation [Matthew Thode]
  + Minor cleanups to atomic_helper and add unit tests.
  + azure dhclient-hook cleanups
  + network: fix get_interface_mac for bond slave, read_sys_net for ENOTDIR
  + Generate a dummy bond name for OpenStack (LP: #1605749)
  + add install option for openrc [Matthew Thode]
  + Add a module that can configure spacewalk.
  + python2.6: fix dict comprehension usage in _lsb_release.
  + apt-config: allow both old and new format to be present.
  [Christian Ehrhardt] (LP: #1616831)
  + bddeb: add --release flag to specify the release in changelog.
  + salt minion: update default pki directory for newer salt minion.
  (LP: #1609899)
  + Fix typo in default keys for phone_home [Roland Sommer] (LP: #1607810)
  + apt config conversion: treat empty string as not provided.  (LP: #1621180)
  + tests: cleanup tempdirs in apt_source tests
  + systemd: Better support package and upgrade. (LP: #1576692, #1621336)
  + remove obsolete .bzrignore
  + DataSourceOVF: fix user-data as base64 with python3 (LP: #1619394)
  + Allow link type of null in network_data.json [Jon Grimm] (LP: #1621968)
  from 0.7.7:
  + Digital Ocean: add datasource for Digital Ocean. [Neal Shrader]
  + expose uses_systemd as a distro function (fix rhel7)
  + fix broken 'output' config (LP: #1387340)
  + begin adding cloud config module docs to config modules (LP: #1383510)
  + retain trailing eol from template files (sources.list) when
  rendered with jinja (LP: #1355343)
  + Only use datafiles and initsys addon outside virtualenvs
  + Fix the digital ocean test case on python 2.6
  + Increase the usefulness, robustness, configurability of the chef module
  so that it is more useful, more documented and better for users
  + Fix how '=' signs are not handled that well in ssh_utils (LP: #1391303)
  + Be more tolerant of ssh keys passed into 'ssh_authorized_keys'; allowing
  for list, tuple, set, dict, string types and warning on other unexpected
  types
  + Update to use newer/better OMNIBUS_URL for chef module
  + GCE: Allow base64 encoded user-data (LP: #1404311) [Wayne Witzell III]
  + GCE: use short hostname rather than fqdn (LP: #1383794) [Ben Howard]
  + systemd: make init stage run before login prompts shown [Steve Langasek]
  + hostname: on first boot apply hostname to be same as is written for
  persistent hostname.  (LP: #1246485)
  + remove usage of dmidecode on linux in favor of /sys interface [Ben Howard]
  + python3 support [Barry Warsaw, Daniel Watkins, Josh Harlow] (LP: #1247132)
  + support managing gpt partitions in disk config [Daniel Watkins]
  + Azure: utilze gpt support for ephemeral formating [Daniel Watkins]
  + CloudStack: support fetching password from virtual router [Daniel Watkins]
  (LP: #1422388)
  + readurl, read_file_or_url returns bytes, user must convert as necessary
  + SmartOS: use v2 metadata service (LP: #1436417) [Daniel Watkins]
  + NoCloud: fix local datasource claiming found without explicit dsmode
  + Snappy: add support for installing snappy packages and configuring.
  + systemd: use network-online instead of network.target (LP: #1440180)
  [Steve Langasek]
  + Add functionality to fixate the uid of a newly added user.
  + Don't overwrite the hostname if the user has changed it after we set it.
  + GCE datasource does not handle instance ssh keys (LP: 1403617)
  + sysvinit: make cloud-init-local run before network (LP: #1275098)
  [Surojit Pathak]
  + Azure: do not re-set hostname if user has changed it (LP: #1375252)
  + Fix exception when running with no arguments on Python 3. [Daniel Watkins]
  + Centos: detect/expect use of systemd on centos 7. [Brian Rak]
  + Azure: remove dependency on walinux-agent [Daniel Watkins]
  + EC2: know about eu-central-1 availability-zone (LP: #1456684)
  + Azure: remove password from on-disk ovf-env.xml (LP: #1443311) [Ben Howard]
  + Doc: include information on user-data in OpenStack [Daniel Watkins]
  + Systemd: check for systemd using sd_booted symantics (LP: #1461201)
  [Lars Kellogg-Stedman]
  + Add an rh_subscription module to handle registration of Red Hat instances.
  [Brent Baude]
  + cc_apt_configure: fix importing keys under python3 (LP: #1463373)
  + cc_growpart: fix specification of 'devices' list (LP: #1465436)
  + CloudStack: fix password setting on cloudstack > 4.5.1 (LP: #1464253)
  + GCE: fix determination of availability zone (LP: #1470880)
  + ssh: generate ed25519 host keys (LP: #1461242)
  + distro mirrors: provide datasource to mirror selection code to support
  GCE regional mirrors. (LP: #1470890)
  + add udev rules that identify ephemeral device on Azure (LP: #1411582)
  + _read_dmi_syspath: fix bad log message causing unintended exception
  + rsyslog: add additional configuration mode (LP: #1478103)
  + status_wrapper in main: fix use of print_exc when handling exception
  + reporting: add reporting module for web hook or logging of events.
  + NoCloud: fix consumption of vendordata (LP: #1493453)
  + power_state_change: support 'condition' to disable or enable poweroff
  + ubuntu fan: support for config and installing of ubuntu fan (LP: #1504604)
  + Azure: support extracting SSH key values from ovf-env.xml (LP: #1506244)
  + AltCloud: fix call to udevadm settle (LP: #1507526)
  + Ubuntu templates: modify sources.list template to provide same sources
  as install from server or desktop ISO. (LP: #1177432)
  + cc_mounts: use 'nofail' if system uses systemd. (LP: #1514485)
  + Azure: get instance id from dmi instead of SharedConfig (LP: #1506187)
  + systemd/power_state: fix power_state to work even if cloud-final
  exited non-zero (LP: #1449318)
  + SmartOS: Add support for Joyent LX-Brand Zones (LP: #1540965)
  [Robert C Jennings]
  + systemd: support using systemd-detect-virt to detect container
  (LP: #1539016) [Martin Pitt]
  + docs: fix lock_passwd documentation [Robert C Jennings]
  + Azure: Handle escaped quotes in WALinuxAgentShim.find_endpoint.
  (LP: #1488891) [Dan Watkins]
  + lxd: add support for setting up lxd using 'lxd init' (LP: #1522879)
  + Add Image Customization Parser for VMware vSphere Hypervisor
  Support. [Sankar Tanguturi]
  + timezone: use a symlink rather than copy for /etc/localtime
  unless it is already a file (LP: #1543025).
  + Enable password changing via a hashed string [Alex Sirbu]
  + Added BigStep datasource [Alex Sirbu]
  + No longer run pollinate in seed_random (LP: #1554152)
  + groups: add defalt user to 'lxd' group.  Create groups listed
  for a user if they do not exist. (LP: #1539317)
  + dmi data: fix failure of reading dmi data for unset dmi values
  + doc: mention label for nocloud datasource must be 'cidata' [Peter Hurley]
  + ssh_pwauth: fix module to support 'unchanged' and match behavior
  described in documentation [Chris Cosby]
  + quickly check to see if the previous instance id is still valid to
  avoid dependency on network metadata service on every boot (LP: #1553815)
  + support network configuration in cloud-init --local with support
  device naming via systemd.link.
  + FreeBSD: add support for installing packages, setting password and
  timezone.  Change default user to 'freebsd'. [Ben Arblaster]
  + locale: list unsupported environment settings in warning (LP: #1558069)
  + disk_setup: correctly send --force to mkfs on block devices (LP: #1548772)
  + chef: fix chef install from gems (LP: #1553345)
  + systemd: do not specify After of obsolete syslog.target (LP: #1536964)
  + centos: Ensure that resolve conf object is written as a str (LP: #1479988)
  + chef: straighten out validation_cert and validation_key (LP: #1568940)
  + phone_home: allow usage of fqdn (LP: #1566824) [Ollie Armstrong]
  + cloudstack: Only use DHCPv4 lease files as a datasource (LP: #1576273)
  [Wido den Hollander]
  + Paths: fix instance path if datasource's id has a '/'. (LP: #1575938)
  [Robert Jennings]
  + Ec2: do not retry requests for user-data path on 404.
  + settings on the kernel command line (cc:) override all local settings
  rather than only those in /etc/cloud/cloud.cfg (LP: #1582323)
  + Improve merging documentation [Daniel Watkins]
  + apt sources: support inserting key/key-id only, custom sources.list,
  long gpg key fingerprints with spaces, and dictionary format (LP: #1574113)
  + SmartOS: datasource improvements and support for metadata service
  providing networking information.
  + Datasources: centrally handle 'dsmode' and no longer require datasources
  to "pass" if modules_init should be executed with network access.
  + ConfigDrive: improved support for networking information from
  a network_data.json or older interfaces formated network_config.
  + Change missing Cheetah log warning to debug [Andrew Jorgensen]
  + Remove trailing dot from GCE metadata URL (LP: #1581200) [Phil Roche]
  + support network rendering to sysconfig (for centos and RHEL)
  + write_files: if no permissions are given, just use default without warn.
  + user_data: fix error when user-data is not utf-8 decodable (LP: #1532072)
  + fix mcollective module with python3 (LP: #1597699) [Sergii Golovatiuk]
* Mon Jun  6 2016 joachim.gleissner@suse.com
- Add cloud-init-python2-sigpipe.patch (bsc#903449)
  + Restore SIGPIPE default handler when executing shell scripts
* Tue May  3 2016 rjschwei@suse.com
- Add cloud-init-finalbeforelogin.patch (bsc#978048)
  + Ordering issue, avoid login prompt before cloud-init is finished
* Tue Mar 15 2016 rjschwei@suse.com
- Update suseIntegratedHandler.patch (bsc#971275)
  + Properly handle the package_upgrade configuration option
* Tue Oct  6 2015 rjschwei@suse.com
- Add dependency on jinja2 (bsc#948995,bsc#948996)
* Mon Jun 29 2015 rjschwei@suse.com
- Add no_logic_change.patch to undo upstream logic changes introduced during
  style clean up
* Wed May 20 2015 rjschwei@suse.com
- Properly write the routes file for static networks (bnc#920190)
  + modify suseIntegratedHandler.patch
- Remove suseSetInitCmd.patch
  + is now integrated with suseIntegratedHandler.patch
* Mon Apr 27 2015 rjschwei@suse.com
- pmtools only exist on Intel architecture (bnc#928552)
* Mon Apr 13 2015 tbechtold@suse.com
- update to 0.7.6:
  - open 0.7.6
  - Enable vendordata on CloudSigma datasource (LP: #1303986)
  - Poll on /dev/ttyS1 in CloudSigma datasource only if dmidecode says
    we're running on cloudsigma (LP: #1316475) [Kiril Vladimiroff]
  - SmartOS test: do not require existance of /dev/ttyS1. [LP: #1316597]
  - doc: fix user-groups doc to reference plural ssh-authorized-keys
    (LP: #1327065) [Joern Heissler]
  - fix 'make test' in python 2.6
  - support jinja2 as a templating engine.  Drop the hard requirement on
    cheetah.  This helps in python3 effort. (LP: #1219223)
  - change install path for systemd files to /lib/systemd/system
    [Dimitri John Ledkov]
  - change trunk debian packaging to use pybuild and drop cdbs.
    [Dimitri John Ledkov]
  - SeLinuxGuard: remove invalid check that looked for stat.st_mode in os.lstat.
  - do not write comments in /etc/timezone (LP: #1341710)
  - ubuntu: provide 'ubuntu-init-switch' module to aid in systemd testing.
  - status/result json: remove 'end' entry which was always null
  - systemd: make cloud-init block ssh service startup to guarantee keys
    are generated. [Jordan Evans] (LP: #1333920)
  - default settings: fix typo resulting in OpenStack and GCE not working
    unless config explicitly provided (LP: #1329583) [Garrett Holmstrom])
  - fix rendering resolv.conf if no 'options' are provided (LP: #1328953)
  - docs: fix disk-setup to reference 'table_type' [Rail Aliiev] (LP: #1313114)
  - ssh_authkey_fingerprints: fix bug that prevented disabling the module.
    (LP: #1340903) [Patrick Lucas]
  - no longer use pylint as a checker, fix pep8 [Jay Faulkner].
  - Openstack: do not load some urls twice.
  - FreeBsd: fix initscripts and add working config file [Harm Weites]
  - Datasource: fix broken logic to provide hostname if datasource does not
    provide one
  - Improved and less verbose logging.
  - resizefs: first check that device is writable.
  - configdrive: fix reading of vendor data to be like metadata service reader.
    [Jay Faulkner]
  - resizefs: fix broken background resizing [Jay Faulkner] (LP: #1338614)
  - cc_grub_dpkg: fix EC2 hvm instances to avoid prompt on grub update.
    (LP: #1336855)
  - FreeBsd: support config drive datasource [Joseph bajin]
  - cc_mounts: support creating a swap file
- Refresh addopenSUSEBase.patch
- Refresh setupSUSEsysVInit.diff
- Removed cloudinit-datasources.patch. Applied upstream
- BuildRequires pkg-config. Needed to find correct systemd unit dir.
- Add fix-default-systemd-unit-dir.patch . Use better default for
  systemd system unit dir.
* Tue Feb 24 2015 rjschwei@suse.com
- Fix (bnc#919305 & bnc#918952)
  - Properly handle persistent network device names for OpenNebula
    + add dataSourceOpenNebula.patch
  - Properly set up network mode if interface config file
    + modified suseIntegratedHandler.patch
* Thu Feb  5 2015 tbechtold@suse.com
- Require e2fsprogs for filesystem resizing
* Tue Feb  3 2015 tbechtold@suse.com
- Remove Requires for python-yaml . There's already the right
  requirement for python-PyYAML
* Fri Nov 21 2014 reik.keutterling@nodefall.de
- fixed syntax error in dmidecode on ppc64 patch (bnc#914920)
* Tue Sep 16 2014 ms@suse.de
- users-groups module checks if the account is locked by
  calling 'passwd -l' which is ok but it should not raise
  if the account is already locked. This patch will cause
  lock_passwd to raise only if the account locking failed
  cloud-init-no-user-lock-if-already-locked.patch
* Sat Aug  9 2014 dvlaeev@suse.com
- Make package Arch dependent otherwise package is not installable
  on architectures where dmidecode is not available.
- Avoid to run dmidecode on PowerPC as well
  cloud-init-no-dmidecode-on-ppc64.patch
* Mon Jul 28 2014 rschweikert@suse.com
- declare rsyslog.d only for distros where it is created
  fixes build error on SLE 11
* Mon Jul 28 2014 rschweikert@suse.com
- add dmidecode (pmtools SLE 11) as dependency (bnc #888345)
* Tue Jul 22 2014 dmueller@suse.com
- fix typo in cloud.cfg (gowpart -> growpart)
- add cloudinit-datasources.patch: Fixes datasource list
* Mon Jul  7 2014 rschweikert@suse.com
- fix "typo" the rhel_util module is imported as rhutil, use the
  proper name when accessing (modifies suseIntegratedHandler.patch)
* Thu Jun 26 2014 rschweikert@suse.com
- add rsyslog filter rule to send cloud-init messages to
  /var/log/cloud-init.log
* Wed Jun 25 2014 rschweikert@suse.com
- initialize variable in method setting the instance hostname (BNC #884392)
  modifies: suseIntegratedHandler.patch
* Tue Jun 24 2014 rschweikert@suse.com
- add the python magic for package build on SLE 11
* Tue Jun 24 2014 rschweikert@suse.com
- add more dependencies to ensure commands used by the scripts are present
- add dynamicInitCmd.diff
  + support diffirent init systems across distribution versions for
    service restart
- add suseSetInitCmd.patch
  + properly setup the init command to support proper service restart
* Fri Jun 20 2014 rschweikert@suse.com
- integrate openSUSE and SLE handler code
  + remove openSUSEHandler.diff
  + add suseIntegratedHandler.patch
* Mon Apr 14 2014 rschweikert@suse.com
- update to version 0.7.5
  - open 0.7.5
  - Add a debug log message around import failures
  - add a 'debug' module for easily printing out some information about
    datasource and cloud-init [Shraddha Pandhe]
  - support running apt with 'eatmydata' via configuration token
    apt_get_wrapper (LP: #1236531).
  - convert paths provided in config-drive 'files' to string before writing
    (LP: #1260072).
  - Azure: minor changes in logging output. ensure filenames are strings (not
    unicode).
  - config/cloud.cfg.d/05_logging.cfg: provide a default 'output' setting, to
    redirect cloud-init stderr and stdout /var/log/cloud-init-output.log.
  - drop support for resizing partitions with parted entirely (LP: #1212492).
    This was broken as it was anyway.
  - add support for vendordata in SmartOS and NoCloud datasources.
  - drop dependency on boto for crawling ec2 metadata service.
  - add 'Requires' on sudo (for OpenNebula datasource) in rpm specs, and
    'Recommends' in the debian/control.in [Vlastimil Holer]
  - if mount_info reports /dev/root is a device path for /, then convert
    that to a device via help of kernel cmdline.
  - configdrive: consider partitions as possible datasources if they have
    theh correct filesystem label. [Paul Querna]
  - initial freebsd support [Harm Weites]
  - fix in is_ipv4 to accept IP addresses with a '0' in them.
  - Azure: fix issue when stale data in /var/lib/waagent (LP: #1269626)
  - skip config_modules that declare themselves only verified on a set of
    distros.  Add them to 'unverified_modules' list to run anyway.
  - Add CloudSigma datasource [Kiril Vladimiroff]
  - Add initial support for Gentoo and Arch distributions [Nate House]
  - Add GCE datasource [Vaidas Jablonskis]
  - Add native Openstack datasource which reads openstack metadata
    rather than relying on EC2 data in openstack metadata service.
  - SmartOS, AltCloud: disable running on arm systems due to bug
    (LP: #1243287, #1285686) [Oleg Strikov]
  - Allow running a command to seed random, default is 'pollinate -q'
    (LP: #1286316) [Dustin Kirkland]
  - Write status to /run/cloud-init/status.json for consumption by
    other programs (LP: #1284439)
  - Azure: if a reboot causes ephemeral storage to be re-provisioned
    Then we need to re-format it. (LP: #1292648)
  - OpenNebula: support base64 encoded user-data
    [Enol Fernandez, Peter Kotcauer]
- remove azure_1269626.diff, fix integrated in new version
- rename addopenSUSEBase.diff to addopenSUSEBase.patch, forward port
* Sat Mar 29 2014 rschweikert@suse.com
- fix implementation of the openSUSE handler, properly read the configuration
  from sysconfig
* Wed Mar 19 2014 rschweikert@suse.com
- do not package any none SUSE/openSUSE templates bnc#839707
- add patch openSUSEhostsTemplate.diff to add an openSUSE hosts template
* Wed Mar 19 2014 rschweikert@suse.com
- enable growing of root partition by default bnc#861473
* Tue Mar 18 2014 rschweikert@suse.com
- include the LICENSE
* Mon Mar 17 2014 rschweikert@suse.com
- include in SLE 12 (FATE #315990, #315991, and 316167)
- add patch azure_1269626.diff, fix for upstream bug 1269626
  + Azure instance do not boot properly after a capture operation
* Mon Mar 17 2014 rschweikert@suse.com
- add dependency on growpart to support root partition expansion
* Mon Jan 20 2014 dmueller@suse.com
- add python-jsonpatch, python-pyserial, python-PyYAML requires,
  otherwise it immediately traces on startup
* Sat Jan  4 2014 rschweikert@suse.com
- update to version 0.7.4
  + fix issue mounting 'ephemeral0' if ephemeral0 was an alias for a
    partitioned block device with target filesystem on ephemeral0.1.
    (LP: #1236594)
  + fix DataSourceAzure incompatibility with 2.6 (LP: #1232175)
  + fix power_state_change config module so that example works.  Improve
    its documentation and add reference to 'timeout'
  + support apt-add-archive with 'cloud-archive:' format.  (LP: #1244355)
  + Change SmartOS verb for availability zone (LP: #1249124)
  + documentation fix for boothooks to use 'cloud-init-per'
  + fix resizefs module by supporting kernels that do not have
    /proc/PID/mountinfo.  (LP: #1248625) [Tim Daly Jr.]
  + fix 'make rpm' by removing 0.6.4 entry from ChangeLog (LP: #1241834)
  + fix omnibus chef installer (LP: #1182265) [Chris Wing]
  + small fix for OVF datasource for iso transport on non-iso9660 filesystem
  + determine if upstart version is suitable for
    'initctl reload-configuration' (LP: #1124384).  If so, then invoke it.
    supports setting up instance-store disk with partition table and filesystem.
  + add Azure datasource.
  + add support for SuSE / SLES [Juerg Haefliger]
  + add a trailing carriage return to chpasswd input, which reportedly
    caused a problem on rhel5 if missing.
  + support individual MIME segments to be gzip compressed (LP: #1203203)
  + always finalize handlers even if processing failed (LP: #1203368)
  + support merging into cloud-config via jsonp. (LP: #1200476)
  + add datasource 'SmartOS' for Joyent Cloud.  Adds a dependency on serial.
  + add 'log_time' helper to util for timing how long things take
    which also reads from uptime. uptime is useful as clock may change during
    boot due to ntp.
  + prefer growpart resizer to 'parted resizepart' (LP: #1212492)
  + support random data seed from config drive or azure, and a module
    'seed_random' to read that and write it to /dev/urandom.
  + add OpenNebula Datasource [Vlastimil Holer]
  + add 'cc_disk_setup' config module for paritioning disks and creating
    filesystems.  Useful if attached disks are not formatted (LP: #1218506)
  + Fix usage of libselinux-python when selinux is disabled. [Garrett Holmstrom]
  + multi_log: only write to /dev/console if it exists [Garrett Holmstrom]
  + config/cloud.cfg: add 'sudo' to list groups for the default user
    (LP: #1228228)
  + documentation fix for use of 'mkpasswd' [Eric Nordlund]
  + respect /etc/growroot-disabled file (LP: #1234331)
- replace fixupSysVinit.patch with suseSysVInit.diff
  + sysV init files are now maintained by distribution, thus we need a patch
    that has the complete sysV init files rather then modifying existing files
- remove slesHandler.patch
  + SLES support is now integrated upstream
- add addopenSUSEBase.diff
  + remnants of the slesHandler.patch that add information about openSUSE
- add setupSUSEsysVInit.diff
  + integrate the SUSE sysV init scripts into setup.py
* Fri Aug  2 2013 rschweikert@suse.com
- remove the "nofail" option for the ephemeral storage
  + when using nofail an attempt is made to mount the filesystem twice
    once via udev and once through localfs, this results in a hanging
    system if fsck needs to run on the device
* Thu Jul 11 2013 speilicke@suse.com
- Install service files into /lib/systemd/system on 12.2, the UsrMove
  happened afterwards
* Wed Jul 10 2013 speilicke@suse.com
- Re-imported from IBS and some cleanup
- Package LICENSE
- Install service files to /usr/lib/systemd/system, not /etc/...
- Drop %%py_requires, there are several autorequires for SLES and openSUSE
- Drop $all facility Required-Start in sysvinit/cloud-final
* Wed Jun 26 2013 bwiedemann@suse.com
- require python-boto >= 2.7 because it fails with 2.5.2
* Wed Jun 26 2013 rschweikert@suse.com
- fix stray character in patch introduced by previous changes
* Wed Jun 26 2013 rschweikert@suse.com
- fix zypper command in slesHandler, use non-interactive mode
* Wed Jun 19 2013 rschweikert@suse.com
- fix duplicate entry in the config w.r.t. ssh key generation
- fix distro indicator setting, sles vs. opensuse
* Tue Jun 18 2013 rschweikert@suse.com
- Integrate the sysV init script changes from Jens
* Tue Jun 18 2013 rschweikert@suse.com
- integrate changes from HP
  + update the sles handler, do not modify the util code integrate
    routines directky into the sles handler
    ~ add patch slesHandler.patch
    ~ remove patch openSUSEHandler.diff
  + add python dependencies
    ~ python-argparse
    ~ python-configobj
    ~ python-oauth
  + update the cloud-init config file
* Sat Jun 15 2013 rschweikert@suse.com
- add the distro specific handler for openSUSE
  + patch openSUSEHandler.diff
- fix syntax in SLE handler
  + dict access uses [] not {}, duh
* Fri Jun 14 2013 rschweikert@suse.com
- add the distro specific handler for SLE
  + patch slesHandler.diff
* Wed Jun  5 2013 rschweikert@suse.com
- update to version 0.7.2, see Changelog in source for fixes
- use the upstream sysvinit and systemd files
- remove all previously created patches
  + drop-MAAS-datasource.diff
  + drop-python27-only-code.diff
  + drop-ubuntu-default-username.diff
  + relative-authorized-keys-file.diff
- create a doc and test package to reduce size of main package
- add patch (fixupSysVinit.patch) to fix the upstream sysvinit LSB headers
* Mon May  6 2013 jdsn@suse.de
- support relative path for authorized_keys file
  backport fix from upstream version 0.7.1 (bnc#818306)
* Wed Sep 19 2012 jdsn@suse.de
- fix usage of patches for openSUSE builds
* Thu Sep 13 2012 jdsn@suse.de
- drop ubuntu as default user name
- disable ssh ecdsa host key creation on SLE11
* Wed Sep 12 2012 jdsn@suse.de
- replace python 2.7 code with 2.5 compliant code
* Tue Sep 11 2012 jdsn@suse.de
- drop debian specific checks (bnc#779553)
* Mon Sep 10 2012 jdsn@suse.com
- Add python-xml Requires that was missing (bnc#779588).
* Fri Jul 20 2012 jdsn@suse.com
- fix init script, use killproc for stop operation (bnc#771803)
* Tue Jul  3 2012 cthiel@suse.com
- change license to SPDX format
* Wed Jun 27 2012 jdsn@suse.de
- rename to cloud-init
- drop MAAS support to avoid oauth dependency
